=== modified file 'bzrlib/plugins/weave_fmt/test_bzrdir.py'
--- bzrlib/plugins/weave_fmt/test_bzrdir.py	2011-03-11 23:20:50 +0000
+++ bzrlib/plugins/weave_fmt/test_bzrdir.py	2011-04-15 22:57:31 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -297,8 +297,6 @@
         t = self.get_transport('.')
         t.delete_multi(['.bzr/pending-merges', '.bzr/inventory'])
         self.assertFalse(t.has('.bzr/stat-cache'))
-        # XXX: upgrade fails if a backup.bzr is already present
-        # -- David Allouche 2006-08-11
         t.delete_tree('backup.bzr.~1~')
         # At this point, we have a format6 branch without checkout files.
         upgrade.upgrade('.', bzrdir.BzrDirMetaFormat1())
@@ -308,7 +306,7 @@
         # We have covered the scope of this test, we may as well check that
         # upgrade has not eaten our data, even if it's a bit redundant with
         # other tests.
-        self.failUnless(isinstance(control._format, bzrdir.BzrDirMetaFormat1))
+        self.assertIsInstance(control._format, bzrdir.BzrDirMetaFormat1)
         b = control.open_branch()
         self.assertEquals(b.revision_history(),
            ['mbp@sourcefrog.net-20051004035611-176b16534b086b3c',
@@ -322,10 +320,9 @@
         control = bzrdir.BzrDir.open('.')
         b = control.open_branch()
         # tsk, peeking under the covers.
-        self.failUnless(
-            isinstance(
-                control._format,
-                bzrdir.BzrDirFormat.get_default_format().__class__))
+        self.assertIsInstance(
+            control._format,
+            bzrdir.BzrDirFormat.get_default_format().__class__)
         rh = b.revision_history()
         eq(rh,
            ['mbp@sourcefrog.net-20051004035611-176b16534b086b3c',
@@ -421,15 +418,15 @@
         # old format branches use a special lock file on sftp.
         b = self.make_branch('', format=BzrDirFormat6())
         b = branch.Branch.open(self.get_url())
-        self.failUnlessExists('.bzr/')
-        self.failUnlessExists('.bzr/branch-format')
-        self.failUnlessExists('.bzr/branch-lock')
+        self.assertPathExists('.bzr/')
+        self.assertPathExists('.bzr/branch-format')
+        self.assertPathExists('.bzr/branch-lock')
 
-        self.failIf(lexists('.bzr/branch-lock.write-lock'))
+        self.assertPathDoesNotExist('.bzr/branch-lock.write-lock')
         b.lock_write()
-        self.failUnlessExists('.bzr/branch-lock.write-lock')
+        self.assertPathExists('.bzr/branch-lock.write-lock')
         b.unlock()
-        self.failIf(lexists('.bzr/branch-lock.write-lock'))
+        self.assertPathDoesNotExist('.bzr/branch-lock.write-lock')
 
 
 class TestInfo(TestCaseWithTransport):

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2011-04-14 07:53:38 +0000
+++ bzrlib/tests/__init__.py	2011-04-15 06:48:43 +0000
@@ -1444,7 +1444,7 @@
 
     def assertFileEqual(self, content, path):
         """Fail if path does not contain 'content'."""
-        self.failUnlessExists(path)
+        self.assertPathExists(path)
         f = file(path, 'rb')
         try:
             s = f.read()
@@ -1460,20 +1460,28 @@
         else:
             self.assertEqual(expected_docstring, obj.__doc__)
 
+    @symbol_versioning.deprecated_method(symbol_versioning.deprecated_in((2, 4)))
     def failUnlessExists(self, path):
+        return self.assertPathExists(path)
+
+    def assertPathExists(self, path):
         """Fail unless path or paths, which may be abs or relative, exist."""
         if not isinstance(path, basestring):
             for p in path:
-                self.failUnlessExists(p)
+                self.assertPathExists(p)
         else:
             self.assertTrue(osutils.lexists(path),
                 path + " does not exist")
 
+    @symbol_versioning.deprecated_method(symbol_versioning.deprecated_in((2, 4)))
     def failIfExists(self, path):
+        return self.assertPathDoesNotExist(path)
+
+    def assertPathDoesNotExist(self, path):
         """Fail if path or paths, which may be abs or relative, exist."""
         if not isinstance(path, basestring):
             for p in path:
-                self.failIfExists(p)
+                self.assertPathDoesNotExist(p)
         else:
             self.assertFalse(osutils.lexists(path),
                 path + " exists")

=== modified file 'bzrlib/tests/blackbox/test_bound_branches.py'
--- bzrlib/tests/blackbox/test_bound_branches.py	2011-03-10 13:49:44 +0000
+++ bzrlib/tests/blackbox/test_bound_branches.py	2011-04-15 07:01:22 +0000
@@ -337,7 +337,7 @@
 
         child_tree.merge_from_branch(other_branch)
 
-        self.failUnlessExists('child/c')
+        self.assertPathExists('child/c')
         self.assertEqual([new_rev_id], child_tree.get_parent_ids()[1:])
 
         # Make sure the local branch has the installed revision

=== modified file 'bzrlib/tests/blackbox/test_branch.py'
--- bzrlib/tests/blackbox/test_branch.py	2011-02-11 05:57:31 +0000
+++ bzrlib/tests/blackbox/test_branch.py	2011-04-15 07:01:22 +0000
@@ -179,7 +179,7 @@
         source.add('file1')
         source.commit('added file')
         out, err = self.run_bzr('branch source target --files-from source')
-        self.failUnlessExists('target/file1')
+        self.assertPathExists('target/file1')
 
     def test_branch_files_from_hardlink(self):
         self.requireFeature(HardlinkFeature)
@@ -208,8 +208,8 @@
     def test_branch_no_tree(self):
         self.example_branch('source')
         self.run_bzr('branch --no-tree source target')
-        self.failIfExists('target/hello')
-        self.failIfExists('target/goodbye')
+        self.assertPathDoesNotExist('target/hello')
+        self.assertPathDoesNotExist('target/goodbye')
 
     def test_branch_into_existing_dir(self):
         self.example_branch('a')
@@ -225,8 +225,8 @@
         # force operation
         self.run_bzr('branch a b --use-existing-dir')
         # check conflicts
-        self.failUnlessExists('b/hello.moved')
-        self.failIfExists('b/godbye.moved')
+        self.assertPathExists('b/hello.moved')
+        self.assertPathDoesNotExist('b/godbye.moved')
         # we can't branch into branch
         out,err = self.run_bzr('branch a b --use-existing-dir', retcode=3)
         self.assertEqual('', out)

=== modified file 'bzrlib/tests/blackbox/test_checkout.py'
--- bzrlib/tests/blackbox/test_checkout.py	2010-12-02 10:41:05 +0000
+++ bzrlib/tests/blackbox/test_checkout.py	2011-04-15 07:01:22 +0000
@@ -69,7 +69,7 @@
         # from 1.
         result = bzrdir.BzrDir.open('checkout')
         self.assertEqual(['1'], result.open_workingtree().get_parent_ids())
-        self.failIfExists('checkout/added_in_2')
+        self.assertPathDoesNotExist('checkout/added_in_2')
 
     def test_checkout_light_dash_r(self):
         out, err = self.run_bzr(['checkout','--lightweight', '-r', '-2',
@@ -78,7 +78,7 @@
         # from 1.
         result = bzrdir.BzrDir.open('checkout')
         self.assertEqual(['1'], result.open_workingtree().get_parent_ids())
-        self.failIfExists('checkout/added_in_2')
+        self.assertPathDoesNotExist('checkout/added_in_2')
 
     def test_checkout_reconstitutes_working_trees(self):
         # doing a 'bzr checkout' in the directory of a branch with no tree
@@ -124,9 +124,9 @@
             cmd.append('--lightweight')
         self.run_bzr('checkout source target')
         # files with unique content should be moved
-        self.failUnlessExists('target/file2.moved')
+        self.assertPathExists('target/file2.moved')
         # files with content matching tree should not be moved
-        self.failIfExists('target/file1.moved')
+        self.assertPathDoesNotExist('target/file1.moved')
 
     def test_checkout_existing_dir_heavy(self):
         self._test_checkout_existing_dir(False)

=== modified file 'bzrlib/tests/blackbox/test_clean_tree.py'
--- bzrlib/tests/blackbox/test_clean_tree.py	2010-05-20 02:57:52 +0000
+++ bzrlib/tests/blackbox/test_clean_tree.py	2011-04-15 07:01:22 +0000
@@ -41,28 +41,28 @@
         self.run_bzr('ignore *.pyc')
         self.touch('name')
         self.touch('name~')
-        self.failUnlessExists('name~')
+        self.assertPathExists('name~')
         self.touch('name.pyc')
         self.run_bzr('clean-tree --force')
-        self.failUnlessExists('name~')
-        self.failIfExists('name')
+        self.assertPathExists('name~')
+        self.assertPathDoesNotExist('name')
         self.touch('name')
         self.run_bzr('clean-tree --detritus --force')
-        self.failUnlessExists('name')
-        self.failIfExists('name~')
-        self.failUnlessExists('name.pyc')
+        self.assertPathExists('name')
+        self.assertPathDoesNotExist('name~')
+        self.assertPathExists('name.pyc')
         self.run_bzr('clean-tree --ignored --force')
-        self.failUnlessExists('name')
-        self.failIfExists('name.pyc')
+        self.assertPathExists('name')
+        self.assertPathDoesNotExist('name.pyc')
         self.run_bzr('clean-tree --unknown --force')
-        self.failIfExists('name')
+        self.assertPathDoesNotExist('name')
         self.touch('name')
         self.touch('name~')
         self.touch('name.pyc')
         self.run_bzr('clean-tree --unknown --ignored --force')
-        self.failIfExists('name')
-        self.failIfExists('name~')
-        self.failIfExists('name.pyc')
+        self.assertPathDoesNotExist('name')
+        self.assertPathDoesNotExist('name~')
+        self.assertPathDoesNotExist('name.pyc')
 
     def test_clean_tree_nested_bzrdir(self):
         # clean-tree should not blindly delete nested bzrdirs (branches)
@@ -73,11 +73,11 @@
         wt3 = self.make_branch_and_tree('bar')
         ignores.tree_ignores_add_patterns(wt1, ['./foo'])
         self.run_bzr(['clean-tree', '--unknown', '--force'])
-        self.failUnlessExists('foo')
-        self.failUnlessExists('bar')
+        self.assertPathExists('foo')
+        self.assertPathExists('bar')
         self.run_bzr(['clean-tree', '--ignored', '--force'])
-        self.failUnlessExists('foo')
-        self.failUnlessExists('bar')
+        self.assertPathExists('foo')
+        self.assertPathExists('bar')
 
     def test_clean_tree_directory(self):
         """Test --directory option"""
@@ -85,6 +85,6 @@
         self.build_tree(['a/added', 'a/unknown', 'a/ignored'])
         tree.add('added')
         self.run_bzr('clean-tree -d a --unknown --ignored --force')
-        self.failIfExists('a/unknown')
-        self.failIfExists('a/ignored')
-        self.failUnlessExists('a/added')
+        self.assertPathDoesNotExist('a/unknown')
+        self.assertPathDoesNotExist('a/ignored')
+        self.assertPathExists('a/added')

=== modified file 'bzrlib/tests/blackbox/test_export.py'
--- bzrlib/tests/blackbox/test_export.py	2011-04-14 07:53:38 +0000
+++ bzrlib/tests/blackbox/test_export.py	2011-04-15 07:01:22 +0000
@@ -334,7 +334,7 @@
         os.chdir('branch')
 
         self.run_bzr('export ../first.zip -r 1')
-        self.failUnlessExists('../first.zip')
+        self.assertPathExists('../first.zip')
         zf = zipfile.ZipFile('../first.zip')
         try:
             self.assertEqual(['first/hello'], sorted(zf.namelist()))

=== modified file 'bzrlib/tests/blackbox/test_init.py'
--- bzrlib/tests/blackbox/test_init.py	2011-04-14 07:53:38 +0000
+++ bzrlib/tests/blackbox/test_init.py	2011-04-15 07:01:22 +0000
@@ -154,7 +154,7 @@
         self.run_bzr_error(['Parent directory of ../new/tree does not exist'],
                             'init ../new/tree', working_dir='tree')
         self.run_bzr('init ../new/tree --create-prefix', working_dir='tree')
-        self.failUnlessExists('new/tree/.bzr')
+        self.assertPathExists('new/tree/.bzr')
 
     def test_init_default_format_option(self):
         """bzr init should read default format from option default_format"""

=== modified file 'bzrlib/tests/blackbox/test_merge.py'
--- bzrlib/tests/blackbox/test_merge.py	2011-04-14 07:53:38 +0000
+++ bzrlib/tests/blackbox/test_merge.py	2011-04-15 07:01:22 +0000
@@ -203,12 +203,12 @@
         b_tree.commit(message='Modified a.txt')
         os.chdir('b')
         self.run_bzr('merge ../a/', retcode=1)
-        self.failUnlessExists('sub/a.txt.THIS')
-        self.failUnlessExists('sub/a.txt.BASE')
+        self.assertPathExists('sub/a.txt.THIS')
+        self.assertPathExists('sub/a.txt.BASE')
         os.chdir('../a')
         self.run_bzr('merge ../b/', retcode=1)
-        self.failUnlessExists('sub/a.txt.OTHER')
-        self.failUnlessExists('sub/a.txt.BASE')
+        self.assertPathExists('sub/a.txt.OTHER')
+        self.assertPathExists('sub/a.txt.BASE')
 
     def test_conflict_leaves_base_this_other_files(self):
         tree, other = self.create_conflicting_branches()
@@ -325,14 +325,14 @@
         tree_a.add(['file_1', 'file_2'])
         tree_a.commit('commit 1')
         tree_b = tree_a.bzrdir.sprout('b').open_workingtree()
-        self.failUnlessExists('b/file_1')
+        self.assertPathExists('b/file_1')
         tree_a.rename_one('file_1', 'file_i')
         tree_a.commit('commit 2')
         tree_a.rename_one('file_2', 'file_ii')
         ## os.chdir('b')
         self.run_bzr('merge a --uncommitted -d b')
-        self.failUnlessExists('b/file_1')
-        self.failUnlessExists('b/file_ii')
+        self.assertPathExists('b/file_1')
+        self.assertPathExists('b/file_ii')
         tree_b.revert()
         self.run_bzr_error(('Cannot use --uncommitted and --revision',),
                            'merge /a --uncommitted -r1 -d b')
@@ -346,8 +346,8 @@
         tree_a.add(['file1', 'file2'])
         os.chdir('tree_b')
         self.run_bzr(['merge', '--uncommitted', '../tree_a/file1'])
-        self.failUnlessExists('file1')
-        self.failIfExists('file2')
+        self.assertPathExists('file1')
+        self.assertPathDoesNotExist('file2')
 
     def pullable_branch(self):
         tree_a = self.make_branch_and_tree('a')
@@ -407,8 +407,8 @@
         self.write_directive('directive', source.branch, 'target', 'rev2',
                              'rev1')
         out, err = self.run_bzr('merge -d target directive')
-        self.failIfExists('target/a')
-        self.failUnlessExists('target/b')
+        self.assertPathDoesNotExist('target/a')
+        self.assertPathExists('target/b')
         self.assertContainsRe(err, 'Performing cherrypick')
 
     def write_directive(self, filename, source, target, revision_id,
@@ -449,19 +449,19 @@
         branch_b.add('file2')
         branch_b.commit('added file2', rev_id='rev2b')
         branch_b.merge_from_branch(branch_a.branch)
-        self.failUnlessExists('branch_b/file1')
+        self.assertPathExists('branch_b/file1')
         branch_b.commit('merged branch_a', rev_id='rev3b')
 
         # It works if the revid has an interger revno
         self.run_bzr('merge -d target -r revid:rev2a branch_a')
-        self.failUnlessExists('target/file1')
-        self.failIfExists('target/file2')
+        self.assertPathExists('target/file1')
+        self.assertPathDoesNotExist('target/file2')
         target.revert()
 
         # It should work if the revid has no integer revno
         self.run_bzr('merge -d target -r revid:rev2a branch_b')
-        self.failUnlessExists('target/file1')
-        self.failIfExists('target/file2')
+        self.assertPathExists('target/file1')
+        self.assertPathDoesNotExist('target/file2')
 
     def assertDirectoryContent(self, directory, entries, message=''):
         """Assert whether entries (file or directories) exist in a directory.
@@ -602,7 +602,7 @@
         other.add('other_file')
         other.commit('rev1b')
         self.run_bzr('merge -d this other -r0..')
-        self.failUnlessExists('this/other_file')
+        self.assertPathExists('this/other_file')
 
     def test_merge_interactive_unlocks_branch(self):
         this = self.make_branch_and_tree('this')
@@ -620,9 +620,9 @@
             tree.commit("added "+f)
         for context in (".", "", "a"):
             self.run_bzr("merge -r 1..0 " + context)
-            self.failIfExists("a")
+            self.assertPathDoesNotExist("a")
             tree.revert()
-            self.failUnlessExists("a")
+            self.assertPathExists("a")
 
     def test_merge_fetches_tags(self):
         """Tags are updated by merge, and revisions named in those tags are

=== modified file 'bzrlib/tests/blackbox/test_mv.py'
--- bzrlib/tests/blackbox/test_mv.py	2011-01-26 16:27:31 +0000
+++ bzrlib/tests/blackbox/test_mv.py	2011-04-15 07:01:22 +0000
@@ -36,10 +36,10 @@
 
     def assertMoved(self,from_path,to_path):
         """Assert that to_path is existing and versioned but from_path not. """
-        self.failIfExists(from_path)
+        self.assertPathDoesNotExist(from_path)
         self.assertNotInWorkingTree(from_path)
 
-        self.failUnlessExists(to_path)
+        self.assertPathExists(to_path)
         self.assertInWorkingTree(to_path)
 
     def test_mv_modes(self):
@@ -120,7 +120,7 @@
 
         os.chdir('sub1/sub2')
         self.run_bzr('mv ../hello.txt .')
-        self.failUnlessExists('./hello.txt')
+        self.assertPathExists('./hello.txt')
 
         os.chdir('..')
         self.run_bzr('mv sub2/hello.txt .')
@@ -230,8 +230,8 @@
             ["^bzr: ERROR: Could not move a => b. b is already versioned\.$"],
             'mv a b')
         #check that nothing changed
-        self.failIfExists('a')
-        self.failUnlessExists('b')
+        self.assertPathDoesNotExist('a')
+        self.assertPathExists('b')
 
     def test_mv_already_moved_file_into_subdir(self):
         """Test bzr mv original_file to versioned_directory/file.
@@ -265,8 +265,8 @@
         self.run_bzr_error(
             ["^bzr: ERROR: Could not move a => a: sub is not versioned\.$"],
             'mv a sub/a')
-        self.failIfExists('a')
-        self.failUnlessExists('sub/a')
+        self.assertPathDoesNotExist('a')
+        self.assertPathExists('sub/a')
 
     def test_mv_already_moved_files_into_subdir(self):
         """Test bzr mv original_files to versioned_directory.
@@ -301,10 +301,10 @@
         self.run_bzr_error(
             ["^bzr: ERROR: Could not move to sub. sub is not versioned\.$"],
             'mv a1 a2 sub')
-        self.failIfExists('a1')
-        self.failUnlessExists('sub/a1')
-        self.failUnlessExists('a2')
-        self.failIfExists('sub/a2')
+        self.assertPathDoesNotExist('a1')
+        self.assertPathExists('sub/a1')
+        self.assertPathExists('a2')
+        self.assertPathDoesNotExist('sub/a2')
 
     def test_mv_already_moved_file_forcing_after(self):
         """Test bzr mv versioned_file to unversioned_file.
@@ -326,8 +326,8 @@
              " \(Use --after to tell bzr about a rename that has already"
              " happened\)$"],
             'mv a b')
-        self.failUnlessExists('a')
-        self.failUnlessExists('b')
+        self.assertPathExists('a')
+        self.assertPathExists('b')
 
     def test_mv_already_moved_file_using_after(self):
         """Test bzr mv --after versioned_file to unversioned_file.
@@ -347,9 +347,9 @@
         self.build_tree(['a']) #touch a
 
         self.run_bzr('mv a b --after')
-        self.failUnlessExists('a')
+        self.assertPathExists('a')
         self.assertNotInWorkingTree('a')#a should be unknown now.
-        self.failUnlessExists('b')
+        self.assertPathExists('b')
         self.assertInWorkingTree('b')
 
     def test_mv_already_moved_files_forcing_after(self):
@@ -376,10 +376,10 @@
              " exist. \(Use --after to tell bzr about a rename that has already"
              " happened\)$"],
             'mv a1 a2 sub')
-        self.failUnlessExists('a1')
-        self.failUnlessExists('a2')
-        self.failUnlessExists('sub/a1')
-        self.failUnlessExists('sub/a2')
+        self.assertPathExists('a1')
+        self.assertPathExists('a2')
+        self.assertPathExists('sub/a1')
+        self.assertPathExists('sub/a2')
 
     def test_mv_already_moved_files_using_after(self):
         """Test bzr mv --after versioned_file to directory/unversioned_file.
@@ -403,10 +403,10 @@
         self.build_tree(['a2']) #touch a2
 
         self.run_bzr('mv a1 a2 sub --after')
-        self.failUnlessExists('a1')
-        self.failUnlessExists('a2')
-        self.failUnlessExists('sub/a1')
-        self.failUnlessExists('sub/a2')
+        self.assertPathExists('a1')
+        self.assertPathExists('a2')
+        self.assertPathExists('sub/a1')
+        self.assertPathExists('sub/a2')
         self.assertInWorkingTree('sub/a1')
         self.assertInWorkingTree('sub/a2')
 
@@ -422,15 +422,15 @@
         osutils.rename('c', 'd')
         # mv a b should work just like it does for already renamed files
         self.run_bzr('mv a b')
-        self.failIfExists('a')
+        self.assertPathDoesNotExist('a')
         self.assertNotInWorkingTree('a')
-        self.failUnlessExists('b')
+        self.assertPathExists('b')
         self.assertInWorkingTree('b')
         # and --after should work, too (technically it's ignored)
         self.run_bzr('mv --after c d')
-        self.failIfExists('c')
+        self.assertPathDoesNotExist('c')
         self.assertNotInWorkingTree('c')
-        self.failUnlessExists('d')
+        self.assertPathExists('d')
         self.assertInWorkingTree('d')
 
     def make_abcd_tree(self):

=== modified file 'bzrlib/tests/blackbox/test_non_ascii.py'
--- bzrlib/tests/blackbox/test_non_ascii.py	2011-04-14 07:53:38 +0000
+++ bzrlib/tests/blackbox/test_non_ascii.py	2011-04-15 07:01:22 +0000
@@ -222,8 +222,8 @@
 
         txt = self.run_bzr_decode(['mv', 'a', fname2])
         self.assertEqual(u'a => %s\n' % fname2, txt)
-        self.failIfExists('a')
-        self.failUnlessExists(fname2)
+        self.assertPathDoesNotExist('a')
+        self.assertPathExists(fname2)
 
         # After 'mv' we need to re-open the working tree
         self.wt = self.wt.bzrdir.open_workingtree()
@@ -240,7 +240,7 @@
         # The rename should still succeed
         newpath = u'%s/%s' % (dirname, fname2)
         txt = self.run_bzr_decode(['mv', newpath, 'a'], encoding='ascii')
-        self.failUnlessExists('a')
+        self.assertPathExists('a')
         self.assertEqual(newpath.encode('ascii', 'replace') + ' => a\n', txt)
 
     def test_branch(self):

=== modified file 'bzrlib/tests/blackbox/test_push.py'
--- bzrlib/tests/blackbox/test_push.py	2011-03-21 14:35:33 +0000
+++ bzrlib/tests/blackbox/test_push.py	2011-04-15 07:01:22 +0000
@@ -135,7 +135,7 @@
         out, err = self.run_bzr('push --no-tree -d push-from push-to')
         self.assertEqual('', out)
         self.assertEqual('Created new branch.\n', err)
-        self.failIfExists('push-to/file')
+        self.assertPathDoesNotExist('push-to/file')
 
     def test_push_new_branch_revision_count(self):
         # bzr push of a branch with revisions to a new location
@@ -199,10 +199,10 @@
         t.commit(allow_pointless=True,
                 message='first commit')
         self.run_bzr('push -d from to-one')
-        self.failUnlessExists('to-one')
+        self.assertPathExists('to-one')
         self.run_bzr('push -d %s %s'
             % tuple(map(urlutils.local_path_to_url, ['from', 'to-two'])))
-        self.failUnlessExists('to-two')
+        self.assertPathExists('to-two')
 
     def test_push_repository_no_branch_doesnt_fetch_all_revs(self):
         # See https://bugs.launchpad.net/bzr/+bug/465517
@@ -324,7 +324,7 @@
                      working_dir='tree')
         new_tree = workingtree.WorkingTree.open('new/tree')
         self.assertEqual(tree.last_revision(), new_tree.last_revision())
-        self.failUnlessExists('new/tree/a')
+        self.assertPathExists('new/tree/a')
 
     def test_push_use_existing(self):
         """'bzr push --use-existing-dir' can push into an existing dir.
@@ -345,7 +345,7 @@
         new_tree = workingtree.WorkingTree.open('target')
         self.assertEqual(tree.last_revision(), new_tree.last_revision())
         # The push should have created target/a
-        self.failUnlessExists('target/a')
+        self.assertPathExists('target/a')
 
     def test_push_use_existing_into_empty_bzrdir(self):
         """'bzr push --use-existing-dir' into a dir with an empty .bzr dir

=== modified file 'bzrlib/tests/blackbox/test_reconfigure.py'
--- bzrlib/tests/blackbox/test_reconfigure.py	2010-11-26 17:33:55 +0000
+++ bzrlib/tests/blackbox/test_reconfigure.py	2011-04-15 07:01:22 +0000
@@ -131,7 +131,7 @@
         tree.add('foo')
         self.run_bzr('reconfigure --with-no-trees --force',
             working_dir='repo/branch')
-        self.failUnlessExists('repo/branch/foo')
+        self.assertPathExists('repo/branch/foo')
         tree = workingtree.WorkingTree.open('repo/branch')
 
     def test_shared_format_to_standalone(self, format=None):

=== modified file 'bzrlib/tests/blackbox/test_remerge.py'
--- bzrlib/tests/blackbox/test_remerge.py	2011-04-14 07:53:38 +0000
+++ bzrlib/tests/blackbox/test_remerge.py	2011-04-15 07:01:22 +0000
@@ -74,8 +74,8 @@
                            'remerge hello --merge-type weave',
                            retcode=1)
 
-        self.failUnlessExists('hello.OTHER')
-        self.failIfExists('question.OTHER')
+        self.assertPathExists('hello.OTHER')
+        self.assertPathDoesNotExist('question.OTHER')
 
         file_id = self.run_bzr('file-id hello')[0]
         self.run_bzr_error(['hello.THIS is not versioned'],
@@ -84,7 +84,7 @@
         self.run_bzr_error(['conflicts encountered'],
                            'remerge --merge-type weave', retcode=1)
 
-        self.failUnlessExists('hello.OTHER')
+        self.assertPathExists('hello.OTHER')
         self.assertTrue('hello.BASE')
         self.assertFalse('|||||||' in conflict_text)
         self.assertFalse('hi world' in conflict_text)

=== modified file 'bzrlib/tests/blackbox/test_remove.py'
--- bzrlib/tests/blackbox/test_remove.py	2010-10-02 18:10:06 +0000
+++ bzrlib/tests/blackbox/test_remove.py	2011-04-15 07:01:22 +0000
@@ -53,12 +53,12 @@
         for f in files:
             id=f+_id
             self.assertNotInWorkingTree(f)
-            self.failIfExists(f)
+            self.assertPathDoesNotExist(f)
 
     def assertFilesUnversioned(self, files):
         for f in files:
             self.assertNotInWorkingTree(f)
-            self.failUnlessExists(f)
+            self.assertPathExists(f)
 
     def changeFile(self, file_name):
         f = file(file_name, 'ab')
@@ -80,7 +80,7 @@
         self.assertEqual('', err)
         self.assertEqual('', out)
         self.assertInWorkingTree('foo', tree=tree)
-        self.failUnlessExists('foo')
+        self.assertPathExists('foo')
 
     def test_remove_no_files_specified_missing_dir_and_contents(self):
         tree = self._make_tree_and_add(
@@ -94,9 +94,9 @@
             err)
         # non-missing paths not touched:
         self.assertInWorkingTree('foo', tree=tree)
-        self.failUnlessExists('foo')
+        self.assertPathExists('foo')
         self.assertInWorkingTree('dir', tree=tree)
-        self.failUnlessExists('dir')
+        self.assertPathExists('dir')
         # missing files unversioned
         self.assertNotInWorkingTree('dir/missing', tree=tree)
         self.assertNotInWorkingTree('dir/missing/child', tree=tree)
@@ -120,7 +120,7 @@
         self.assertEqual('removed bar\n', err)
         # non-missing files not touched:
         self.assertInWorkingTree('foo', tree=tree)
-        self.failUnlessExists('foo')
+        self.assertPathExists('foo')
         # missing files unversioned
         self.assertNotInWorkingTree('bar', tree=tree)
 
@@ -135,7 +135,7 @@
         self.assertEqual('removed linkname\n', err)
         # non-missing files not touched:
         self.assertInWorkingTree('foo', tree=tree)
-        self.failUnlessExists('foo')
+        self.assertPathExists('foo')
         # missing files unversioned
         self.assertNotInWorkingTree('linkname', tree=tree)
 
@@ -196,7 +196,7 @@
         self.run_bzr_remove_changed_files(
             ['../a', 'c', '.', '../d'], working_dir='b')
         self.assertNotInWorkingTree(files)
-        self.failIfExists(files)
+        self.assertPathDoesNotExist(files)
 
     def test_remove_keep_unversioned_files(self):
         self.build_tree(files)
@@ -237,10 +237,10 @@
         for f in my_files:
             osutils.delete_any(f)
         self.assertInWorkingTree(files)
-        self.failIfExists(files)
+        self.assertPathDoesNotExist(files)
         self.run_bzr('remove ' + ' '.join(files))
         self.assertNotInWorkingTree(a)
-        self.failIfExists(files)
+        self.assertPathDoesNotExist(files)
 
     def test_remove_non_existing_files(self):
         tree = self._make_tree_and_add([])

=== modified file 'bzrlib/tests/blackbox/test_remove_tree.py'
--- bzrlib/tests/blackbox/test_remove_tree.py	2010-06-23 08:19:28 +0000
+++ bzrlib/tests/blackbox/test_remove_tree.py	2011-04-15 07:01:22 +0000
@@ -31,75 +31,75 @@
         self.build_tree(['branch1/foo'])
         self.tree.add('foo')
         self.tree.commit('1')
-        self.failUnlessExists('branch1/foo')
+        self.assertPathExists('branch1/foo')
 
     # Success modes
 
     def test_remove_tree_original_branch(self):
         os.chdir('branch1')
         self.run_bzr('remove-tree')
-        self.failIfExists('foo')
+        self.assertPathDoesNotExist('foo')
 
     def test_remove_tree_original_branch_explicit(self):
         self.run_bzr('remove-tree branch1')
-        self.failIfExists('branch1/foo')
+        self.assertPathDoesNotExist('branch1/foo')
 
     def test_remove_tree_multiple_branch_explicit(self):
         self.tree.bzrdir.sprout('branch2')
         self.run_bzr('remove-tree branch1 branch2')
-        self.failIfExists('branch1/foo')
-        self.failIfExists('branch2/foo')
+        self.assertPathDoesNotExist('branch1/foo')
+        self.assertPathDoesNotExist('branch2/foo')
 
     def test_remove_tree_sprouted_branch(self):
         self.tree.bzrdir.sprout('branch2')
-        self.failUnlessExists('branch2/foo')
+        self.assertPathExists('branch2/foo')
         os.chdir('branch2')
         self.run_bzr('remove-tree')
-        self.failIfExists('foo')
+        self.assertPathDoesNotExist('foo')
 
     def test_remove_tree_sprouted_branch_explicit(self):
         self.tree.bzrdir.sprout('branch2')
-        self.failUnlessExists('branch2/foo')
+        self.assertPathExists('branch2/foo')
         self.run_bzr('remove-tree branch2')
-        self.failIfExists('branch2/foo')
+        self.assertPathDoesNotExist('branch2/foo')
 
     def test_remove_tree_checkout(self):
         self.tree.branch.create_checkout('branch2', lightweight=False)
-        self.failUnlessExists('branch2/foo')
+        self.assertPathExists('branch2/foo')
         os.chdir('branch2')
         self.run_bzr('remove-tree')
-        self.failIfExists('foo')
+        self.assertPathDoesNotExist('foo')
         os.chdir('..')
-        self.failUnlessExists('branch1/foo')
+        self.assertPathExists('branch1/foo')
 
     def test_remove_tree_checkout_explicit(self):
         self.tree.branch.create_checkout('branch2', lightweight=False)
-        self.failUnlessExists('branch2/foo')
+        self.assertPathExists('branch2/foo')
         self.run_bzr('remove-tree branch2')
-        self.failIfExists('branch2/foo')
-        self.failUnlessExists('branch1/foo')
+        self.assertPathDoesNotExist('branch2/foo')
+        self.assertPathExists('branch1/foo')
 
     # Failure modes
 
     def test_remove_tree_lightweight_checkout(self):
         self.tree.branch.create_checkout('branch2', lightweight=True)
-        self.failUnlessExists('branch2/foo')
+        self.assertPathExists('branch2/foo')
         os.chdir('branch2')
         output = self.run_bzr_error(
             ["You cannot remove the working tree from a lightweight checkout"],
             'remove-tree', retcode=3)
-        self.failUnlessExists('foo')
+        self.assertPathExists('foo')
         os.chdir('..')
-        self.failUnlessExists('branch1/foo')
+        self.assertPathExists('branch1/foo')
 
     def test_remove_tree_lightweight_checkout_explicit(self):
         self.tree.branch.create_checkout('branch2', lightweight=True)
-        self.failUnlessExists('branch2/foo')
+        self.assertPathExists('branch2/foo')
         output = self.run_bzr_error(
             ["You cannot remove the working tree from a lightweight checkout"],
             'remove-tree branch2', retcode=3)
-        self.failUnlessExists('branch2/foo')
-        self.failUnlessExists('branch1/foo')
+        self.assertPathExists('branch2/foo')
+        self.assertPathExists('branch1/foo')
 
     def test_remove_tree_empty_dir(self):
         os.mkdir('branch2')
@@ -109,7 +109,7 @@
 
     def test_remove_tree_repeatedly(self):
         self.run_bzr('remove-tree branch1')
-        self.failIfExists('branch1/foo')
+        self.assertPathDoesNotExist('branch1/foo')
         output = self.run_bzr_error(["No working tree to remove"],
                                     'remove-tree branch1', retcode=3)
 
@@ -127,19 +127,19 @@
         self.build_tree(['branch1/bar'])
         self.tree.add('bar')
         self.run_bzr('remove-tree branch1 --force')
-        self.failIfExists('branch1/foo')
-        self.failUnlessExists('branch1/bar')
+        self.assertPathDoesNotExist('branch1/foo')
+        self.assertPathExists('branch1/bar')
 
     def test_remove_tree_pending_merges(self):
         self.run_bzr(['branch', 'branch1', 'branch2'])
         self.build_tree(['branch1/bar'])
         self.tree.add('bar')
         self.tree.commit('2')
-        self.failUnlessExists('branch1/bar')
+        self.assertPathExists('branch1/bar')
         self.run_bzr(['merge', '../branch1'], working_dir='branch2')
-        self.failUnlessExists('branch2/bar')
+        self.assertPathExists('branch2/bar')
         self.run_bzr(['revert', '.'], working_dir='branch2')
-        self.failIfExists('branch2/bar')
+        self.assertPathDoesNotExist('branch2/bar')
         output = self.run_bzr_error(["Working tree .* has uncommitted changes"],
                                     'remove-tree branch2', retcode=3)
 
@@ -148,14 +148,14 @@
         self.build_tree(['branch1/bar'])
         self.tree.add('bar')
         self.tree.commit('2')
-        self.failUnlessExists('branch1/bar')
+        self.assertPathExists('branch1/bar')
         self.run_bzr(['merge', '../branch1'], working_dir='branch2')
-        self.failUnlessExists('branch2/bar')
+        self.assertPathExists('branch2/bar')
         self.run_bzr(['revert', '.'], working_dir='branch2')
-        self.failIfExists('branch2/bar')
+        self.assertPathDoesNotExist('branch2/bar')
         self.run_bzr('remove-tree branch2 --force')
-        self.failIfExists('branch2/foo')
-        self.failIfExists('branch2/bar')
+        self.assertPathDoesNotExist('branch2/foo')
+        self.assertPathDoesNotExist('branch2/bar')
 
     def test_remove_tree_shelved_changes(self):
         # https://bugs.launchpad.net/bzr/+bug/586639

=== modified file 'bzrlib/tests/blackbox/test_repair_workingtree.py'
--- bzrlib/tests/blackbox/test_repair_workingtree.py	2011-01-27 16:27:05 +0000
+++ bzrlib/tests/blackbox/test_repair_workingtree.py	2011-04-15 07:01:22 +0000
@@ -33,7 +33,7 @@
         try:
             dirstate = tree.current_dirstate()
             dirstate_path = dirstate._filename
-            self.failUnlessExists(dirstate_path)
+            self.assertPathExists(dirstate_path)
         finally:
             tree.unlock()
         # We have to have the tree unlocked at this point, so we can safely
@@ -72,7 +72,7 @@
         self.run_bzr('repair-workingtree -d tree --force')
         # This requires the tree has reloaded the working state
         self.assertIs(None, tree.path2id('alt_dir'))
-        self.failUnlessExists('tree/alt_dir')
+        self.assertPathExists('tree/alt_dir')
 
     def test_repair_corrupted_dirstate(self):
         tree = self.make_initial_tree()

=== modified file 'bzrlib/tests/blackbox/test_revert.py'
--- bzrlib/tests/blackbox/test_revert.py	2010-06-23 08:19:28 +0000
+++ bzrlib/tests/blackbox/test_revert.py	2011-04-15 07:01:22 +0000
@@ -93,17 +93,17 @@
         """Test that revert DIRECTORY does what's expected"""
         self._prepare_rename_mod_tree()
         self.run_bzr('revert a')
-        self.failUnlessExists('a/b')
-        self.failUnlessExists('a/d')
-        self.failIfExists('a/g')
+        self.assertPathExists('a/b')
+        self.assertPathExists('a/d')
+        self.assertPathDoesNotExist('a/g')
         self.expectFailure(
             "j is in the delta revert applies because j was renamed too",
-            self.failUnlessExists, 'j')
-        self.failUnlessExists('h')
+            self.assertPathExists, 'j')
+        self.assertPathExists('h')
         self.run_bzr('revert f')
-        self.failIfExists('j')
-        self.failIfExists('h')
-        self.failUnlessExists('a/d/e')
+        self.assertPathDoesNotExist('j')
+        self.assertPathDoesNotExist('h')
+        self.assertPathExists('a/d/e')
 
     def test_revert_chatter(self):
         self._prepare_rename_mod_tree()
@@ -148,7 +148,7 @@
             self.run_bzr('commit -m f')
             os.unlink('symlink')
             self.run_bzr('revert')
-            self.failUnlessExists('symlink')
+            self.assertPathExists('symlink')
             os.unlink('symlink')
             os.symlink('a-different-path', 'symlink')
             self.run_bzr('revert')

=== modified file 'bzrlib/tests/blackbox/test_rmbranch.py'
--- bzrlib/tests/blackbox/test_rmbranch.py	2010-06-11 07:32:12 +0000
+++ bzrlib/tests/blackbox/test_rmbranch.py	2011-04-15 07:01:22 +0000
@@ -42,8 +42,8 @@
         self.run_bzr('rmbranch a')
         dir = bzrdir.BzrDir.open('a')
         self.assertFalse(dir.has_branch())
-        self.failUnlessExists('a/hello')
-        self.failUnlessExists('a/goodbye')
+        self.assertPathExists('a/hello')
+        self.assertPathExists('a/goodbye')
 
     def test_no_branch(self):
         # No branch in the current directory. 

=== modified file 'bzrlib/tests/blackbox/test_shared_repository.py'
--- bzrlib/tests/blackbox/test_shared_repository.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/blackbox/test_shared_repository.py	2011-04-15 07:01:22 +0000
@@ -88,7 +88,7 @@
         cdir = BzrDir.open('a/c')
         cdir.open_branch()
         self.assertRaises(errors.NoRepositoryPresent, cdir.open_repository)
-        self.failUnlessExists('a/c/hello')
+        self.assertPathExists('a/c/hello')
         cdir.open_workingtree()
 
     def test_trees_default(self):

=== modified file 'bzrlib/tests/blackbox/test_shelve.py'
--- bzrlib/tests/blackbox/test_shelve.py	2010-11-26 17:59:08 +0000
+++ bzrlib/tests/blackbox/test_shelve.py	2011-04-15 07:01:22 +0000
@@ -72,7 +72,7 @@
         self.build_tree(['file'])
         tree.add('file')
         self.run_bzr('shelve --all --destroy')
-        self.failIfExists('file')
+        self.assertPathDoesNotExist('file')
         self.assertIs(None, tree.get_shelf_manager().last_shelf())
 
     def test_unshelve_keep(self):

=== modified file 'bzrlib/tests/blackbox/test_switch.py'
--- bzrlib/tests/blackbox/test_switch.py	2010-06-20 22:54:30 +0000
+++ bzrlib/tests/blackbox/test_switch.py	2011-04-15 07:01:22 +0000
@@ -149,17 +149,17 @@
         tree = self._create_sample_tree()
         checkout = tree.branch.create_checkout('checkout', lightweight=True)
         self.run_bzr(['switch', 'branch-1', '-r1'], working_dir='checkout')
-        self.failUnlessExists('checkout/file-1')
-        self.failIfExists('checkout/file-2')
+        self.assertPathExists('checkout/file-1')
+        self.assertPathDoesNotExist('checkout/file-2')
 
     def test_switch_only_revision(self):
         tree = self._create_sample_tree()
         checkout = tree.branch.create_checkout('checkout', lightweight=True)
-        self.failUnlessExists('checkout/file-1')
-        self.failUnlessExists('checkout/file-2')
+        self.assertPathExists('checkout/file-1')
+        self.assertPathExists('checkout/file-2')
         self.run_bzr(['switch', '-r1'], working_dir='checkout')
-        self.failUnlessExists('checkout/file-1')
-        self.failIfExists('checkout/file-2')
+        self.assertPathExists('checkout/file-1')
+        self.assertPathDoesNotExist('checkout/file-2')
         # Check that we don't accept a range
         self.run_bzr_error(
             ['bzr switch --revision takes exactly one revision identifier'],

=== modified file 'bzrlib/tests/blackbox/test_too_much.py'
--- bzrlib/tests/blackbox/test_too_much.py	2011-04-14 07:53:38 +0000
+++ bzrlib/tests/blackbox/test_too_much.py	2011-04-15 07:01:22 +0000
@@ -88,7 +88,7 @@
             self.run_bzr('commit -m f')
             os.unlink('symlink')
             self.run_bzr('revert')
-            self.failUnlessExists('symlink')
+            self.assertPathExists('symlink')
             os.unlink('symlink')
             os.symlink('a-different-path', 'symlink')
             self.run_bzr('revert')

=== modified file 'bzrlib/tests/blackbox/test_update.py'
--- bzrlib/tests/blackbox/test_update.py	2010-09-27 20:22:57 +0000
+++ bzrlib/tests/blackbox/test_update.py	2011-04-15 07:01:22 +0000
@@ -90,7 +90,7 @@
 Updated to revision 1 of branch %s
 """ % osutils.pathjoin(self.test_dir, 'branch',),
                          err)
-        self.failUnlessExists('branch/file')
+        self.assertPathExists('branch/file')
 
     def test_update_out_of_date_light_checkout(self):
         self.make_branch_and_tree('branch')
@@ -179,9 +179,9 @@
 """ % osutils.pathjoin(self.test_dir, 'master',),
                          err)
         self.assertEqual([master_tip, child_tip], wt.get_parent_ids())
-        self.failUnlessExists('checkout/file')
-        self.failUnlessExists('checkout/file_b')
-        self.failUnlessExists('checkout/file_c')
+        self.assertPathExists('checkout/file')
+        self.assertPathExists('checkout/file_b')
+        self.assertPathExists('checkout/file_c')
         self.assertTrue(wt.has_filename('file_c'))
 
     def test_update_with_merges(self):
@@ -299,8 +299,8 @@
 2>All changes applied successfully.
 2>Updated to revision 1 of .../master
 ''')
-        self.failUnlessExists('./file1')
-        self.failIfExists('./file2')
+        self.assertPathExists('./file1')
+        self.assertPathDoesNotExist('./file2')
         self.assertEquals(['m1'], master.get_parent_ids())
 
     def test_update_dash_r_outside_history(self):

=== modified file 'bzrlib/tests/blackbox/test_version.py'
--- bzrlib/tests/blackbox/test_version.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/blackbox/test_version.py	2011-04-15 07:01:22 +0000
@@ -108,12 +108,12 @@
         bzr_log = 'my.bzr.log'
         self.overrideEnv('BZR_LOG', bzr_log)
         default_log = os.path.join(os.environ['BZR_HOME'], '.bzr.log')
-        self.failIfExists([default_log, bzr_log])
+        self.assertPathDoesNotExist([default_log, bzr_log])
         out = self.run_bzr_subprocess('version')[0]
         self.assertTrue(len(out) > 0)
         self.assertContainsRe(out, r"(?m)^  Bazaar log file: " + bzr_log)
-        self.failIfExists(default_log)
-        self.failUnlessExists(bzr_log)
+        self.assertPathDoesNotExist(default_log)
+        self.assertPathExists(bzr_log)
 
     def test_dev_null(self):
         # This test uses a subprocess to cause the log opening logic to
@@ -124,8 +124,8 @@
             bzr_log = '/dev/null'
         self.overrideEnv('BZR_LOG', bzr_log)
         default_log = os.path.join(os.environ['BZR_HOME'], '.bzr.log')
-        self.failIfExists(default_log)
+        self.assertPathDoesNotExist(default_log)
         out = self.run_bzr_subprocess('version')[0]
         self.assertTrue(len(out) > 0)
         self.assertContainsRe(out, r"(?m)^  Bazaar log file: " + bzr_log)
-        self.failIfExists(default_log)
+        self.assertPathDoesNotExist(default_log)

=== modified file 'bzrlib/tests/blackbox/test_versioning.py'
--- bzrlib/tests/blackbox/test_versioning.py	2011-04-14 07:53:38 +0000
+++ bzrlib/tests/blackbox/test_versioning.py	2011-04-15 07:01:22 +0000
@@ -39,7 +39,7 @@
         # here locally.
         shared_repo = self.make_repository('.')
         self.run_bzr(['mkdir', 'abc'], retcode=3)
-        self.failIfExists('abc')
+        self.assertPathDoesNotExist('abc')
 
 
 class TestVersioning(TestCaseInTempDir):

=== modified file 'bzrlib/tests/doc_generate/builders/test_texinfo.py'
--- bzrlib/tests/doc_generate/builders/test_texinfo.py	2011-03-11 11:33:33 +0000
+++ bzrlib/tests/doc_generate/builders/test_texinfo.py	2011-04-15 07:01:22 +0000
@@ -67,5 +67,5 @@
              ])
         app, out, err = self.make_sphinx()
         self.build(app)
-        self.failUnlessExists('index.texi')
-        self.failUnlessExists('content.texi')
+        self.assertPathExists('index.texi')
+        self.assertPathExists('content.texi')

=== modified file 'bzrlib/tests/per_branch/test_bound_sftp.py'
--- bzrlib/tests/per_branch/test_bound_sftp.py	2011-04-14 07:53:38 +0000
+++ bzrlib/tests/per_branch/test_bound_sftp.py	2011-04-15 07:01:22 +0000
@@ -94,8 +94,8 @@
         # this line is more of a working tree test line, but - what the hey,
         # it has work to do.
         b_child.bzrdir.open_workingtree().update()
-        self.failUnlessExists('child/a')
-        self.failUnlessExists('child/b')
+        self.assertPathExists('child/a')
+        self.assertPathExists('child/b')
 
         b_child.unbind()
         self.assertEqual(None, b_child.get_bound_location())
@@ -297,7 +297,7 @@
 
         wt_child.merge_from_branch(wt_other.branch)
 
-        self.failUnlessExists('child/c')
+        self.assertPathExists('child/c')
         self.assertEqual(['r@d-2'], wt_child.get_parent_ids()[1:])
         self.assertTrue(wt_child.branch.repository.has_revision('r@d-2'))
         self.assertFalse(b_base.repository.has_revision('r@d-2'))

=== modified file 'bzrlib/tests/per_branch/test_create_checkout.py'
--- bzrlib/tests/per_branch/test_create_checkout.py	2010-02-10 17:52:08 +0000
+++ bzrlib/tests/per_branch/test_create_checkout.py	2011-04-15 07:01:22 +0000
@@ -46,8 +46,8 @@
 
         tree2 = tree1.branch.create_checkout('checkout', revision_id='rev-1')
         self.assertEqual('rev-1', tree2.last_revision())
-        self.failUnlessExists('checkout/a')
-        self.failIfExists('checkout/b')
+        self.assertPathExists('checkout/a')
+        self.assertPathDoesNotExist('checkout/b')
 
     def test_create_lightweight_checkout(self):
         """We should be able to make a lightweight checkout."""

=== modified file 'bzrlib/tests/per_branch/test_sprout.py'
--- bzrlib/tests/per_branch/test_sprout.py	2011-03-11 21:06:09 +0000
+++ bzrlib/tests/per_branch/test_sprout.py	2011-04-15 07:01:22 +0000
@@ -144,7 +144,7 @@
         wt2 = wt.bzrdir.sprout('target',
             revision_id='rev1a').open_workingtree()
         self.assertEqual('rev1a', wt2.last_revision())
-        self.failUnlessExists('target/a')
+        self.assertPathExists('target/a')
 
     def test_sprout_with_unicode_symlink(self):
         # this tests bug #272444

=== modified file 'bzrlib/tests/per_controldir/test_controldir.py'
--- bzrlib/tests/per_controldir/test_controldir.py	2011-04-14 07:53:38 +0000
+++ bzrlib/tests/per_controldir/test_controldir.py	2011-04-15 07:01:22 +0000
@@ -122,12 +122,12 @@
             bzrdir.destroy_workingtree()
         except errors.UnsupportedOperation:
             raise TestSkipped('Format does not support destroying tree')
-        self.failIfExists('tree/file')
+        self.assertPathDoesNotExist('tree/file')
         self.assertRaises(errors.NoWorkingTree, bzrdir.open_workingtree)
         bzrdir.create_workingtree()
-        self.failUnlessExists('tree/file')
+        self.assertPathExists('tree/file')
         bzrdir.destroy_workingtree_metadata()
-        self.failUnlessExists('tree/file')
+        self.assertPathExists('tree/file')
         self.assertRaises(errors.NoWorkingTree, bzrdir.open_workingtree)
 
     def test_destroy_branch(self):
@@ -860,7 +860,7 @@
                 create_tree_if_local=False)
         except errors.MustHaveWorkingTree:
             raise TestNotApplicable("control dir format requires working tree")
-        self.failIfExists('target/foo')
+        self.assertPathDoesNotExist('target/foo')
         self.assertEqual(tree.branch.last_revision(),
                          target.open_branch().last_revision())
 
@@ -1409,8 +1409,8 @@
         old_url, new_url = tree.bzrdir.backup_bzrdir()
         old_path = urlutils.local_path_from_url(old_url)
         new_path = urlutils.local_path_from_url(new_url)
-        self.failUnlessExists(old_path)
-        self.failUnlessExists(new_path)
+        self.assertPathExists(old_path)
+        self.assertPathExists(new_path)
         for (((dir_relpath1, _), entries1),
              ((dir_relpath2, _), entries2)) in izip(
                 osutils.walkdirs(old_path),

=== modified file 'bzrlib/tests/per_workingtree/test_check_state.py'
--- bzrlib/tests/per_workingtree/test_check_state.py	2011-01-25 23:21:46 +0000
+++ bzrlib/tests/per_workingtree/test_check_state.py	2011-04-15 07:01:22 +0000
@@ -40,7 +40,7 @@
         try:
             dirstate = tree.current_dirstate()
             dirstate_path = dirstate._filename
-            self.failUnlessExists(dirstate_path)
+            self.assertPathExists(dirstate_path)
         finally:
             tree.unlock()
         # We have to have the tree unlocked at this point, so we can safely
@@ -88,8 +88,8 @@
         # have
         self.assertEqual(foo_id, tree.path2id('foo'))
         self.assertEqual(None, tree.path2id('baz'))
-        self.failIfExists('tree/foo')
-        self.failUnlessExists('tree/baz')
+        self.assertPathDoesNotExist('tree/foo')
+        self.assertPathExists('tree/baz')
 
     def test_reset_state_handles_corrupted_dirstate(self):
         tree = self.make_initial_tree()

=== modified file 'bzrlib/tests/per_workingtree/test_move.py'
--- bzrlib/tests/per_workingtree/test_move.py	2011-01-26 16:31:43 +0000
+++ bzrlib/tests/per_workingtree/test_move.py	2011-04-15 07:01:22 +0000
@@ -174,7 +174,7 @@
                                ('b/c', 'c-id')], tree)
         self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),
                                ('b/c', 'c-id')], tree.basis_tree())
-        self.failIfExists('a')
+        self.assertPathDoesNotExist('a')
         self.assertFileEqual(a_contents, 'b/a')
         tree._validate()
 
@@ -191,7 +191,7 @@
                                ('c', 'c-id')], tree)
         self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),
                                ('b/c', 'c-id')], tree.basis_tree())
-        self.failIfExists('b/c')
+        self.assertPathDoesNotExist('b/c')
         self.assertFileEqual(c_contents, 'c')
         tree._validate()
 
@@ -210,7 +210,7 @@
             self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),
                                    ('c', 'c-id')], tree)
         else:
-            self.failUnlessExists('b/c')
+            self.assertPathExists('b/c')
             self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),
                                    ('b/c', 'c-id')], tree)
         self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),

=== modified file 'bzrlib/tests/per_workingtree/test_pull.py'
--- bzrlib/tests/per_workingtree/test_pull.py	2011-04-14 07:53:38 +0000
+++ bzrlib/tests/per_workingtree/test_pull.py	2011-04-15 07:01:22 +0000
@@ -99,4 +99,4 @@
         work.pull(trunk)
         self.assertLength(0, work.conflicts())
         # The directory removal should succeed
-        self.failIfExists('work/dir')
+        self.assertPathDoesNotExist('work/dir')

=== modified file 'bzrlib/tests/per_workingtree/test_remove.py'
--- bzrlib/tests/per_workingtree/test_remove.py	2010-08-20 09:39:20 +0000
+++ bzrlib/tests/per_workingtree/test_remove.py	2011-04-15 07:01:22 +0000
@@ -29,7 +29,7 @@
     def get_tree(self, files):
         tree = self.make_branch_and_tree('.')
         self.build_tree(files)
-        self.failUnlessExists(files)
+        self.assertPathExists(files)
         return tree
 
     def get_committed_tree(self, files, message="Committing"):
@@ -41,11 +41,11 @@
 
     def assertRemovedAndDeleted(self, files):
         self.assertNotInWorkingTree(files)
-        self.failIfExists(files)
+        self.assertPathDoesNotExist(files)
 
     def assertRemovedAndNotDeleted(self, files):
         self.assertNotInWorkingTree(files)
-        self.failUnlessExists(files)
+        self.assertPathExists(files)
 
     def test_remove_keep(self):
         """Check that files and directories are unversioned but not deleted."""
@@ -79,7 +79,7 @@
         self.assertInWorkingTree(TestRemove.files)
         tree.remove(TestRemove.files, keep_files=False)
         self.assertNotInWorkingTree(TestRemove.files)
-        self.failUnlessExists(TestRemove.backup_files)
+        self.assertPathExists(TestRemove.backup_files)
         tree._validate()
 
     def test_remove_changed_file(self):
@@ -89,7 +89,7 @@
         self.assertInWorkingTree('a')
         tree.remove('a', keep_files=False)
         self.assertNotInWorkingTree(TestRemove.files)
-        self.failUnlessExists('a.~1~')
+        self.assertPathExists('a.~1~')
         tree._validate()
 
     def test_remove_deleted_files(self):
@@ -98,7 +98,7 @@
         for f in TestRemove.rfiles:
             osutils.delete_any(f)
         self.assertInWorkingTree(TestRemove.files)
-        self.failIfExists(TestRemove.files)
+        self.assertPathDoesNotExist(TestRemove.files)
         tree.remove(TestRemove.files, keep_files=False)
         self.assertRemovedAndDeleted(TestRemove.files)
         tree._validate()
@@ -111,7 +111,7 @@
             tree.rename_one(f,f+'x')
         rfilesx = ['bx/cx', 'bx', 'ax', 'dx']
         self.assertInWorkingTree(rfilesx)
-        self.failUnlessExists(rfilesx)
+        self.assertPathExists(rfilesx)
 
         tree.remove(rfilesx, keep_files=False)
         self.assertRemovedAndDeleted(rfilesx)
@@ -127,12 +127,12 @@
         self.build_tree_contents([('ax','changed and renamed!'),
                                   ('bx/cx','changed and renamed!')])
         self.assertInWorkingTree(rfilesx)
-        self.failUnlessExists(rfilesx)
+        self.assertPathExists(rfilesx)
 
         tree.remove(rfilesx, keep_files=False)
         self.assertNotInWorkingTree(rfilesx)
-        self.failUnlessExists(['bx.~1~/cx.~1~', 'bx.~1~', 'ax.~1~'])
-        self.failIfExists('dx.~1~') # unchanged file
+        self.assertPathExists(['bx.~1~/cx.~1~', 'bx.~1~', 'ax.~1~'])
+        self.assertPathDoesNotExist('dx.~1~') # unchanged file
         tree._validate()
 
     def test_force_remove_changed_files(self):
@@ -143,7 +143,7 @@
 
         tree.remove(TestRemove.files, keep_files=False, force=True)
         self.assertRemovedAndDeleted(TestRemove.files)
-        self.failIfExists(['a.~1~', 'b.~1~/', 'b.~1~/c', 'd.~1~/'])
+        self.assertPathDoesNotExist(['a.~1~', 'b.~1~/', 'b.~1~/c', 'd.~1~/'])
         tree._validate()
 
     def test_remove_unknown_files(self):
@@ -151,7 +151,7 @@
         tree = self.get_tree(TestRemove.files)
         tree.remove(TestRemove.files, keep_files=False)
         self.assertRemovedAndDeleted(TestRemove.files)
-        self.failUnlessExists(TestRemove.backup_files)
+        self.assertPathExists(TestRemove.backup_files)
         tree._validate()
 
     def test_remove_nonexisting_files(self):
@@ -206,7 +206,7 @@
 
         tree.remove(files, keep_files=False)
         self.assertNotInWorkingTree(files)
-        self.failUnlessExists('an_ignored_file.~1~')
+        self.assertPathExists('an_ignored_file.~1~')
         tree._validate()
 
     def test_dont_remove_directory_with_unknowns(self):
@@ -216,18 +216,18 @@
 
         self.build_tree(['a/unknown_file'])
         tree.remove('a', keep_files=False)
-        self.failUnlessExists('a.~1~/unknown_file')
+        self.assertPathExists('a.~1~/unknown_file')
 
         self.build_tree(['b/unknown_directory'])
         tree.remove('b', keep_files=False)
-        self.failUnlessExists('b.~1~/unknown_directory')
+        self.assertPathExists('b.~1~/unknown_directory')
 
         self.build_tree(['c/c/unknown_file'])
         tree.remove('c/c', keep_files=False)
-        self.failUnlessExists('c/c.~1~/unknown_file')
+        self.assertPathExists('c/c.~1~/unknown_file')
 
         tree.remove('c', keep_files=False)
-        self.failUnlessExists('c.~1~/')
+        self.assertPathExists('c.~1~/')
 
         self.assertNotInWorkingTree(directories)
         tree._validate()
@@ -242,7 +242,7 @@
         self.build_tree(other_files)
 
         self.assertInWorkingTree(files)
-        self.failUnlessExists(files)
+        self.assertPathExists(files)
 
         tree.remove('b', keep_files=False, force=True)
 
@@ -257,7 +257,7 @@
         self.build_tree_contents([('b/c', "some other new content!")])
 
         tree.remove('b', keep_files=False)
-        self.failUnlessExists('b.~1~/c.~1~')
+        self.assertPathExists('b.~1~/c.~1~')
         self.assertNotInWorkingTree(files)
 
     def test_remove_force_directory_with_changed_file(self):
@@ -281,9 +281,9 @@
         tree.rename_one('somedir/file', 'moved-file')
         tree.remove('somedir', keep_files=False)
         self.assertNotInWorkingTree('somedir')
-        self.failIfExists('somedir')
+        self.assertPathDoesNotExist('somedir')
         self.assertInWorkingTree('moved-file')
-        self.failUnlessExists('moved-file')
+        self.assertPathExists('moved-file')
 
     def test_remove_directory_with_renames(self):
         """Delete directory with renames in or out."""
@@ -298,7 +298,7 @@
         moved_files = ['b/file', 'b/directory/']
         self.assertRemovedAndDeleted(files_to_move)
         self.assertInWorkingTree(moved_files)
-        self.failUnlessExists(moved_files)
+        self.assertPathExists(moved_files)
 
         # check if it works with renames out
         tree.remove('a', keep_files=False)
@@ -315,7 +315,7 @@
         tree.add(['dir', 'dir/file'])
         tree.commit('add file')
         tree.remove('dir/', keep_files=False)
-        self.failIfExists('tree/dir/file')
+        self.assertPathDoesNotExist('tree/dir/file')
         self.assertNotInWorkingTree('tree/dir/file', 'tree')
         tree._validate()
 
@@ -324,15 +324,15 @@
         tree = self.get_committed_tree(['a'])
         tree.remove('a', keep_files=False)
         tree.remove('a', keep_files=False)
-        self.failIfExists('a')
+        self.assertPathDoesNotExist('a')
         tree._validate()
 
     def test_remove_file_and_containing_dir(self):
         tree = self.get_committed_tree(['config/', 'config/file'])
         tree.remove('config/file', keep_files=False)
         tree.remove('config', keep_files=False)
-        self.failIfExists('config/file')
-        self.failIfExists('config')
+        self.assertPathDoesNotExist('config/file')
+        self.assertPathDoesNotExist('config')
         tree._validate()
 
     def test_remove_dir_before_bzr(self):
@@ -340,6 +340,6 @@
         # or the bug doesn't manifest itself.
         tree = self.get_committed_tree(['.aaa/', '.aaa/file'])
         tree.remove('.aaa/', keep_files=False)
-        self.failIfExists('.aaa/file')
-        self.failIfExists('.aaa')
+        self.assertPathDoesNotExist('.aaa/file')
+        self.assertPathDoesNotExist('.aaa')
         tree._validate()

=== modified file 'bzrlib/tests/per_workingtree/test_rename_one.py'
--- bzrlib/tests/per_workingtree/test_rename_one.py	2011-01-26 16:31:43 +0000
+++ bzrlib/tests/per_workingtree/test_rename_one.py	2011-04-15 07:01:22 +0000
@@ -91,7 +91,7 @@
                               tree)
         self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id')],
                               tree.basis_tree())
-        self.failIfExists('a')
+        self.assertPathDoesNotExist('a')
         self.assertFileEqual(a_contents, 'foo')
 
     def test_rename_one_not_localdir(self):
@@ -107,7 +107,7 @@
                               tree)
         self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id')],
                               tree.basis_tree())
-        self.failIfExists('tree/a')
+        self.assertPathDoesNotExist('tree/a')
         self.assertFileEqual(a_contents, 'tree/b/foo')
 
     def test_rename_one_subdir(self):
@@ -126,7 +126,7 @@
                                ('b/d', 'a-id')], tree)
         self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),
                                ('b/c', 'c-id')], tree.basis_tree())
-        self.failIfExists('a')
+        self.assertPathDoesNotExist('a')
         self.assertFileEqual(a_contents, 'b/d')
 
     def test_rename_one_parent_dir(self):
@@ -141,7 +141,7 @@
                                ('d', 'c-id')], tree)
         self.assertTreeLayout([('', root_id), ('a', 'a-id'), ('b', 'b-id'),
                                ('b/c', 'c-id')], tree.basis_tree())
-        self.failIfExists('b/c')
+        self.assertPathDoesNotExist('b/c')
         self.assertFileEqual(c_contents, 'd')
 
     def test_rename_one_fail_consistent(self):

=== modified file 'bzrlib/tests/per_workingtree/test_workingtree.py'
--- bzrlib/tests/per_workingtree/test_workingtree.py	2011-04-14 07:53:38 +0000
+++ bzrlib/tests/per_workingtree/test_workingtree.py	2011-04-15 07:01:22 +0000
@@ -203,7 +203,7 @@
         os.unlink('hello.txt')
         tree.remove('hello.txt')
         tree.revert(['hello.txt'])
-        self.failUnlessExists('hello.txt')
+        self.assertPathExists('hello.txt')
 
     def test_versioned_files_not_unknown(self):
         tree = self.make_branch_and_tree('.')
@@ -464,7 +464,7 @@
         wt.commit('A', rev_id='A')
         # and update old_tree
         self.assertEqual(0, old_tree.update())
-        self.failUnlessExists('checkout/file')
+        self.assertPathExists('checkout/file')
         self.assertEqual(['A'], old_tree.get_parent_ids())
 
     def test_update_sets_root_id(self):
@@ -485,7 +485,7 @@
         wt.commit('A', rev_id='A')
         # and update checkout
         self.assertEqual(0, checkout.update())
-        self.failUnlessExists('checkout/file')
+        self.assertPathExists('checkout/file')
         self.assertEqual(wt.get_root_id(), checkout.get_root_id())
         self.assertNotEqual(None, wt.get_root_id())
 
@@ -566,10 +566,10 @@
             a.close()
         this.revert()
         self.assertFileEqual('a test\n', 'b1/a')
-        self.failUnlessExists('b1/b.~1~')
-        self.failIfExists('b1/c')
-        self.failIfExists('b1/a.~1~')
-        self.failUnlessExists('b1/d')
+        self.assertPathExists('b1/b.~1~')
+        self.assertPathDoesNotExist('b1/c')
+        self.assertPathDoesNotExist('b1/a.~1~')
+        self.assertPathExists('b1/d')
 
     def test_update_updates_bound_branch_no_local_commits(self):
         # doing an update in a tree updates the branch its bound to too.
@@ -1070,9 +1070,9 @@
         self.assertEqual(0, wt.update(revision='1'))
         self.assertEqual('1', wt.last_revision())
         self.assertEqual(tip, wt.branch.last_revision())
-        self.failUnlessExists('checkout/file1')
-        self.failIfExists('checkout/file4')
-        self.failIfExists('checkout/file5')
+        self.assertPathExists('checkout/file1')
+        self.assertPathDoesNotExist('checkout/file4')
+        self.assertPathDoesNotExist('checkout/file5')
 
 
 class TestIllegalPaths(TestCaseWithWorkingTree):

=== modified file 'bzrlib/tests/test_atomicfile.py'
--- bzrlib/tests/test_atomicfile.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_atomicfile.py	2011-04-15 07:01:22 +0000
@@ -33,7 +33,7 @@
 
     def test_commit(self):
         f = atomicfile.AtomicFile('test')
-        self.failIfExists('test')
+        self.assertPathDoesNotExist('test')
         f.write('foo\n')
         f.commit()
 

=== modified file 'bzrlib/tests/test_branch.py'
--- bzrlib/tests/test_branch.py	2011-04-14 07:53:38 +0000
+++ bzrlib/tests/test_branch.py	2011-04-15 07:01:22 +0000
@@ -322,22 +322,22 @@
 
     def test_layout(self):
         branch = self.make_branch('a', format=self.get_format_name())
-        self.failUnlessExists('a/.bzr/branch/last-revision')
-        self.failIfExists('a/.bzr/branch/revision-history')
-        self.failIfExists('a/.bzr/branch/references')
+        self.assertPathExists('a/.bzr/branch/last-revision')
+        self.assertPathDoesNotExist('a/.bzr/branch/revision-history')
+        self.assertPathDoesNotExist('a/.bzr/branch/references')
 
     def test_config(self):
         """Ensure that all configuration data is stored in the branch"""
         branch = self.make_branch('a', format=self.get_format_name())
         branch.set_parent('http://example.com')
-        self.failIfExists('a/.bzr/branch/parent')
+        self.assertPathDoesNotExist('a/.bzr/branch/parent')
         self.assertEqual('http://example.com', branch.get_parent())
         branch.set_push_location('sftp://example.com')
         config = branch.get_config()._get_branch_data_config()
         self.assertEqual('sftp://example.com',
                          config.get_user_option('push_location'))
         branch.set_bound_location('ftp://example.com')
-        self.failIfExists('a/.bzr/branch/bound')
+        self.assertPathDoesNotExist('a/.bzr/branch/bound')
         self.assertEqual('ftp://example.com', branch.get_bound_location())
 
     def test_set_revision_history(self):
@@ -371,10 +371,10 @@
         subtree.commit('a subtree file')
         subsubtree.commit('a subsubtree file')
         tree.branch.create_checkout('target', lightweight=lightweight)
-        self.failUnlessExists('target')
-        self.failUnlessExists('target/subtree')
-        self.failUnlessExists('target/subtree/file')
-        self.failUnlessExists('target/subtree/subsubtree/file')
+        self.assertPathExists('target')
+        self.assertPathExists('target/subtree')
+        self.assertPathExists('target/subtree/file')
+        self.assertPathExists('target/subtree/subsubtree/file')
         subbranch = _mod_branch.Branch.open('target/subtree/subsubtree')
         if lightweight:
             self.assertEndsWith(subbranch.base, 'source/subtree/subsubtree/')

=== modified file 'bzrlib/tests/test_bzrdir.py'
--- bzrlib/tests/test_bzrdir.py	2011-04-14 07:53:38 +0000
+++ bzrlib/tests/test_bzrdir.py	2011-04-15 07:01:22 +0000
@@ -797,7 +797,7 @@
         tree2 = tree.bzrdir.sprout('tree2').open_workingtree()
         tree2.lock_read()
         self.addCleanup(tree2.unlock)
-        self.failUnlessExists('tree2/subtree/file')
+        self.assertPathExists('tree2/subtree/file')
         self.assertEqual('tree-reference', tree2.kind('subtree-root'))
 
     def test_cloning_metadir(self):
@@ -837,8 +837,8 @@
         # #634470.  -- vila 20100909
         self.assertRaises(errors.NotBranchError,
                           tree.bzrdir.sprout, 'repo/tree2')
-#        self.failUnlessExists('repo/tree2/subtree')
-#        self.failIfExists('repo/tree2/subtree/file')
+#        self.assertPathExists('repo/tree2/subtree')
+#        self.assertPathDoesNotExist('repo/tree2/subtree/file')
 
     def make_foo_bar_baz(self):
         foo = bzrdir.BzrDir.create_branch_convenience('foo').bzrdir

=== modified file 'bzrlib/tests/test_clean_tree.py'
--- bzrlib/tests/test_clean_tree.py	2011-01-12 01:01:53 +0000
+++ bzrlib/tests/test_clean_tree.py	2011-04-15 07:01:22 +0000
@@ -46,12 +46,12 @@
         BzrDir.create_standalone_workingtree('branch')
         os.symlink(os.path.realpath('no-die-please'), 'branch/die-please')
         os.mkdir('no-die-please')
-        self.failUnlessExists('branch/die-please')
+        self.assertPathExists('branch/die-please')
         os.mkdir('no-die-please/child')
 
         clean_tree('branch', unknown=True, no_prompt=True)
-        self.failUnlessExists('no-die-please')
-        self.failUnlessExists('no-die-please/child')
+        self.assertPathExists('no-die-please')
+        self.assertPathExists('no-die-please/child')
 
     def test_iter_deletable(self):
         """Files are selected for deletion appropriately"""

=== modified file 'bzrlib/tests/test_conflicts.py'
--- bzrlib/tests/test_conflicts.py	2011-03-03 16:59:21 +0000
+++ bzrlib/tests/test_conflicts.py	2011-04-15 07:01:22 +0000
@@ -446,7 +446,7 @@
         return [('unversion', 'file-id')]
 
     def check_file_doesnt_exist(self):
-        self.failIfExists('branch/file')
+        self.assertPathDoesNotExist('branch/file')
 
     def do_create_file_in_dir(self):
         return [('add', ('dir', 'dir-id', 'directory', '')),
@@ -459,7 +459,7 @@
         self.assertFileEqual('trunk content\nmore content\n', 'branch/dir/file')
 
     def check_file_in_dir_doesnt_exist(self):
-        self.failIfExists('branch/dir/file')
+        self.assertPathDoesNotExist('branch/dir/file')
 
     def _get_resolve_path_arg(self, wt, action):
         return self._path
@@ -540,41 +540,41 @@
         return [('rename', ('file', 'new-file'))]
 
     def check_file_renamed(self):
-        self.failIfExists('branch/file')
-        self.failUnlessExists('branch/new-file')
+        self.assertPathDoesNotExist('branch/file')
+        self.assertPathExists('branch/new-file')
 
     def do_rename_file2(self):
         return [('rename', ('file', 'new-file2'))]
 
     def check_file_renamed2(self):
-        self.failIfExists('branch/file')
-        self.failUnlessExists('branch/new-file2')
+        self.assertPathDoesNotExist('branch/file')
+        self.assertPathExists('branch/new-file2')
 
     def do_rename_dir(self):
         return [('rename', ('dir', 'new-dir'))]
 
     def check_dir_renamed(self):
-        self.failIfExists('branch/dir')
-        self.failUnlessExists('branch/new-dir')
+        self.assertPathDoesNotExist('branch/dir')
+        self.assertPathExists('branch/new-dir')
 
     def do_rename_dir2(self):
         return [('rename', ('dir', 'new-dir2'))]
 
     def check_dir_renamed2(self):
-        self.failIfExists('branch/dir')
-        self.failUnlessExists('branch/new-dir2')
+        self.assertPathDoesNotExist('branch/dir')
+        self.assertPathExists('branch/new-dir2')
 
     def do_delete_file(self):
         return [('unversion', 'file-id')]
 
     def check_file_doesnt_exist(self):
-        self.failIfExists('branch/file')
+        self.assertPathDoesNotExist('branch/file')
 
     def do_delete_dir(self):
         return [('unversion', 'dir-id')]
 
     def check_dir_doesnt_exist(self):
-        self.failIfExists('branch/dir')
+        self.assertPathDoesNotExist('branch/dir')
 
     def do_create_file_in_dir(self):
         return [('add', ('dir', 'dir-id', 'directory', '')),
@@ -584,11 +584,11 @@
         return [('rename', ('dir/file', 'dir/new-file'))]
 
     def check_file_in_dir_renamed(self):
-        self.failIfExists('branch/dir/file')
-        self.failUnlessExists('branch/dir/new-file')
+        self.assertPathDoesNotExist('branch/dir/file')
+        self.assertPathExists('branch/dir/new-file')
 
     def check_file_in_dir_doesnt_exist(self):
-        self.failIfExists('branch/dir/file')
+        self.assertPathDoesNotExist('branch/dir/file')
 
     def _get_resolve_path_arg(self, wt, action):
         tpath = self._this['path']
@@ -885,15 +885,15 @@
         return [('rename', ('dir1', 'dir2/dir1'))]
 
     def check_dir1_moved(self):
-        self.failIfExists('branch/dir1')
-        self.failUnlessExists('branch/dir2/dir1')
+        self.assertPathDoesNotExist('branch/dir1')
+        self.assertPathExists('branch/dir2/dir1')
 
     def do_move_dir2_into_dir1(self):
         return [('rename', ('dir2', 'dir1/dir2'))]
 
     def check_dir2_moved(self):
-        self.failIfExists('branch/dir2')
-        self.failUnlessExists('branch/dir1/dir2')
+        self.assertPathDoesNotExist('branch/dir2')
+        self.assertPathExists('branch/dir1/dir2')
 
     def do_create_dir1_4(self):
         return [('add', ('dir1', 'dir1-id', 'directory', '')),
@@ -905,17 +905,17 @@
         return [('rename', ('dir1', 'dir3/dir4/dir1'))]
 
     def check_dir1_2_moved(self):
-        self.failIfExists('branch/dir1')
-        self.failUnlessExists('branch/dir3/dir4/dir1')
-        self.failUnlessExists('branch/dir3/dir4/dir1/dir2')
+        self.assertPathDoesNotExist('branch/dir1')
+        self.assertPathExists('branch/dir3/dir4/dir1')
+        self.assertPathExists('branch/dir3/dir4/dir1/dir2')
 
     def do_move_dir3_into_dir2(self):
         return [('rename', ('dir3', 'dir1/dir2/dir3'))]
 
     def check_dir3_4_moved(self):
-        self.failIfExists('branch/dir3')
-        self.failUnlessExists('branch/dir1/dir2/dir3')
-        self.failUnlessExists('branch/dir1/dir2/dir3/dir4')
+        self.assertPathDoesNotExist('branch/dir3')
+        self.assertPathExists('branch/dir1/dir2/dir3')
+        self.assertPathExists('branch/dir1/dir2/dir3/dir4')
 
     def _get_resolve_path_arg(self, wt, action):
         # ParentLoop says: moving <conflict_path> into <path>. Cancelled move.

=== modified file 'bzrlib/tests/test_export.py'
--- bzrlib/tests/test_export.py	2011-03-14 23:18:48 +0000
+++ bzrlib/tests/test_export.py	2011-04-15 07:01:22 +0000
@@ -40,8 +40,8 @@
         wt.add(['a', 'a/b', 'a/c'])
         os.unlink('a/c')
         export.export(wt, 'target', format="dir")
-        self.failUnlessExists('target/a/b')
-        self.failIfExists('target/a/c')
+        self.assertPathExists('target/a/b')
+        self.assertPathDoesNotExist('target/a/c')
 
     def test_empty(self):
         wt = self.make_branch_and_tree('.')
@@ -54,7 +54,7 @@
         os.symlink('source', 'link')
         wt.add(['link'])
         export.export(wt, 'target', format="dir")
-        self.failUnlessExists('target/link')
+        self.assertPathExists('target/link')
 
     def test_to_existing_empty_dir_success(self):
         self.build_tree(['source/', 'source/a', 'source/b/', 'source/b/c'])
@@ -63,9 +63,9 @@
         wt.commit('1')
         self.build_tree(['target/'])
         export.export(wt, 'target', format="dir")
-        self.failUnlessExists('target/a')
-        self.failUnlessExists('target/b')
-        self.failUnlessExists('target/b/c')
+        self.assertPathExists('target/a')
+        self.assertPathExists('target/b')
+        self.assertPathExists('target/b/c')
 
     def test_to_existing_nonempty_dir_fail(self):
         self.build_tree(['source/', 'source/a', 'source/b/', 'source/b/c'])
@@ -81,9 +81,9 @@
         wtree.add(['dir2', 'first', 'dir2/second'])
         wtree.commit('1')
         export.export(wtree, 'target1', format='dir', subdir='first')
-        self.failUnlessExists('target1/first')
+        self.assertPathExists('target1/first')
         export.export(wtree, 'target2', format='dir', subdir='dir2/second')
-        self.failUnlessExists('target2/second')
+        self.assertPathExists('target2/second')
 
     def test_files_same_timestamp(self):
         builder = self.make_branch_builder('source')

=== modified file 'bzrlib/tests/test_ignores.py'
--- bzrlib/tests/test_ignores.py	2011-01-12 01:01:53 +0000
+++ bzrlib/tests/test_ignores.py	2011-04-15 07:01:22 +0000
@@ -76,11 +76,11 @@
     def test_create_if_missing(self):
         # $HOME should be set to '.'
         ignore_path = config.user_ignore_config_filename()
-        self.failIfExists(ignore_path)
+        self.assertPathDoesNotExist(ignore_path)
         user_ignores = ignores.get_user_ignores()
         self.assertEqual(set(ignores.USER_DEFAULTS), user_ignores)
 
-        self.failUnlessExists(ignore_path)
+        self.assertPathExists(ignore_path)
         f = open(ignore_path, 'rb')
         try:
             entries = ignores.parse_ignore_file(f)

=== modified file 'bzrlib/tests/test_merge.py'
--- bzrlib/tests/test_merge.py	2011-04-14 07:53:38 +0000
+++ bzrlib/tests/test_merge.py	2011-04-15 07:01:22 +0000
@@ -90,8 +90,8 @@
         os.chdir('branch2')
         self.run_bzr('merge ../branch1/baz', retcode=3)
         self.run_bzr('merge ../branch1/foo')
-        self.failUnlessExists('foo')
-        self.failIfExists('bar')
+        self.assertPathExists('foo')
+        self.assertPathDoesNotExist('bar')
         wt2 = WorkingTree.open('.') # opens branch2
         self.assertEqual([tip], wt2.get_parent_ids())
 

=== modified file 'bzrlib/tests/test_merge_core.py'
--- bzrlib/tests/test_merge_core.py	2011-04-14 07:53:38 +0000
+++ bzrlib/tests/test_merge_core.py	2011-04-15 07:01:22 +0000
@@ -493,16 +493,16 @@
         wtb = d_b.open_workingtree()
         wtb.commit('this revision', allow_pointless=False)
         self.assertEqual(1, wtb.merge_from_branch(wta.branch))
-        self.failUnlessExists('b/file.THIS')
-        self.failUnlessExists('b/file.BASE')
-        self.failUnlessExists('b/file.OTHER')
+        self.assertPathExists('b/file.THIS')
+        self.assertPathExists('b/file.BASE')
+        self.assertPathExists('b/file.OTHER')
         wtb.revert()
         self.assertEqual(1, wtb.merge_from_branch(wta.branch,
                                                   merge_type=WeaveMerger))
-        self.failUnlessExists('b/file')
-        self.failUnlessExists('b/file.THIS')
-        self.failUnlessExists('b/file.BASE')
-        self.failUnlessExists('b/file.OTHER')
+        self.assertPathExists('b/file')
+        self.assertPathExists('b/file.THIS')
+        self.assertPathExists('b/file.BASE')
+        self.assertPathExists('b/file.OTHER')
 
     def test_weave_conflicts_not_in_base(self):
         builder = self.make_branch_builder('source')
@@ -532,11 +532,11 @@
         self.assertEqual(1, tree.merge_from_branch(tree.branch,
                                                    to_revision='D-id',
                                                    merge_type=WeaveMerger))
-        self.failUnlessExists('tree/foo.THIS')
-        self.failUnlessExists('tree/foo.OTHER')
+        self.assertPathExists('tree/foo.THIS')
+        self.assertPathExists('tree/foo.OTHER')
         self.expectFailure('fail to create .BASE in some criss-cross merges',
-            self.failUnlessExists, 'tree/foo.BASE')
-        self.failUnlessExists('tree/foo.BASE')
+            self.assertPathExists, 'tree/foo.BASE')
+        self.assertPathExists('tree/foo.BASE')
 
     def test_merge_unrelated(self):
         """Sucessfully merges unrelated branches with no common names"""
@@ -618,7 +618,7 @@
         b_wt.commit('r1', rev_id='r1')
         self.assertEqual(0, a_wt.merge_from_branch(b_wt.branch,
             b_wt.branch.last_revision(), b_wt.branch.get_rev_id(1)))
-        self.failUnlessExists('a/un')
+        self.assertPathExists('a/un')
         self.assertTrue('a/deux')
         self.assertFalse(os.path.exists('a/tmp'))
         self.assertEqual(file('a/un').read(),'DEUX')

=== modified file 'bzrlib/tests/test_mergetools.py'
--- bzrlib/tests/test_mergetools.py	2011-01-20 04:44:14 +0000
+++ bzrlib/tests/test_mergetools.py	2011-04-15 07:01:22 +0000
@@ -71,7 +71,7 @@
                          'test.txt.OTHER'))
         cmd_list = ['some_tool', '{this_temp}']
         args, tmpfile = mergetools._subst_filename(cmd_list, 'test.txt')
-        self.failUnlessExists(tmpfile)
+        self.assertPathExists(tmpfile)
         os.remove(tmpfile)
 
 
@@ -135,7 +135,7 @@
         def dummy_invoker(exe, args, cleanup):
             self._exe = exe
             self._args = args
-            self.failUnlessExists(args[0])
+            self.assertPathExists(args[0])
             f = open(args[0], 'wt')
             f.write('temp stuff')
             f.close()
@@ -145,14 +145,14 @@
                                     dummy_invoker)
         self.assertEqual(0, retcode)
         self.assertEqual('tool', self._exe)
-        self.failIfExists(self._args[0])
+        self.assertPathDoesNotExist(self._args[0])
         self.assertFileEqual('temp stuff', 'test.txt')
     
     def test_failure_tempfile(self):
         def dummy_invoker(exe, args, cleanup):
             self._exe = exe
             self._args = args
-            self.failUnlessExists(args[0])
+            self.assertPathExists(args[0])
             self.log(repr(args))
             f = open(args[0], 'wt')
             self.log(repr(f))

=== modified file 'bzrlib/tests/test_multiparent.py'
--- bzrlib/tests/test_multiparent.py	2011-01-12 01:01:53 +0000
+++ bzrlib/tests/test_multiparent.py	2011-04-15 07:01:22 +0000
@@ -265,10 +265,10 @@
     def test_filenames(self):
         vf = multiparent.MultiVersionedFile('foop')
         vf.add_version('a\nb\nc\nd'.splitlines(True), 'a', [])
-        self.failUnlessExists('foop.mpknit')
-        self.failIfExists('foop.mpidx')
+        self.assertPathExists('foop.mpknit')
+        self.assertPathDoesNotExist('foop.mpidx')
         vf.save()
-        self.failUnlessExists('foop.mpidx')
+        self.assertPathExists('foop.mpidx')
         vf.destroy()
-        self.failIfExists('foop.mpknit')
-        self.failIfExists('foop.mpidx')
+        self.assertPathDoesNotExist('foop.mpknit')
+        self.assertPathDoesNotExist('foop.mpidx')

=== modified file 'bzrlib/tests/test_osutils.py'
--- bzrlib/tests/test_osutils.py	2011-04-14 07:53:38 +0000
+++ bzrlib/tests/test_osutils.py	2011-04-15 07:01:22 +0000
@@ -134,8 +134,8 @@
         # This should work everywhere
         self.create_file('a', 'something in a\n')
         self._fancy_rename('a', 'b')
-        self.failIfExists('a')
-        self.failUnlessExists('b')
+        self.assertPathDoesNotExist('a')
+        self.assertPathExists('b')
         self.check_file_contents('b', 'something in a\n')
 
         self.create_file('a', 'new something in a\n')
@@ -148,7 +148,7 @@
         self.create_file('target', 'data in target\n')
         self.assertRaises((IOError, OSError), self._fancy_rename,
                           'missingsource', 'target')
-        self.failUnlessExists('target')
+        self.assertPathExists('target')
         self.check_file_contents('target', 'data in target\n')
 
     def test_fancy_rename_fails_if_source_and_target_missing(self):
@@ -159,8 +159,8 @@
         # Rename should be semi-atomic on all platforms
         self.create_file('a', 'something in a\n')
         osutils.rename('a', 'b')
-        self.failIfExists('a')
-        self.failUnlessExists('b')
+        self.assertPathDoesNotExist('a')
+        self.assertPathExists('b')
         self.check_file_contents('b', 'something in a\n')
 
         self.create_file('a', 'new something in a\n')
@@ -267,8 +267,8 @@
 
         osutils.rmtree('dir')
 
-        self.failIfExists('dir/file')
-        self.failIfExists('dir')
+        self.assertPathDoesNotExist('dir/file')
+        self.assertPathDoesNotExist('dir')
 
 
 class TestDeleteAny(tests.TestCaseInTempDir):
@@ -924,8 +924,8 @@
         b.close()
 
         osutils._win32_rename('b', 'a')
-        self.failUnlessExists('a')
-        self.failIfExists('b')
+        self.assertPathExists('a')
+        self.assertPathDoesNotExist('b')
         self.assertFileEqual('baz\n', 'a')
 
     def test_rename_missing_file(self):
@@ -1614,7 +1614,7 @@
                           ('d', 'source/b', 'target/b'),
                           ('f', 'source/b/c', 'target/b/c'),
                          ], processed_files)
-        self.failIfExists('target')
+        self.assertPathDoesNotExist('target')
         if osutils.has_symlinks():
             self.assertEqual([('source/lnk', 'target/lnk')], processed_links)
 

=== modified file 'bzrlib/tests/test_revert.py'
--- bzrlib/tests/test_revert.py	2010-01-11 22:27:17 +0000
+++ bzrlib/tests/test_revert.py	2011-04-15 07:01:22 +0000
@@ -34,11 +34,11 @@
         self.addCleanup(target_tree.unlock)
         merge.merge_inner(target_tree.branch, source_tree.basis_tree(),
                           target_tree.basis_tree(), this_tree=target_tree)
-        self.failUnlessExists('target/dir')
-        self.failUnlessExists('target/dir/contents')
+        self.assertPathExists('target/dir')
+        self.assertPathExists('target/dir/contents')
         target_tree.revert()
-        self.failIfExists('target/dir/contents')
-        self.failIfExists('target/dir')
+        self.assertPathDoesNotExist('target/dir/contents')
+        self.assertPathDoesNotExist('target/dir')
 
     def test_revert_new(self):
         """Only locally-changed new files should be preserved when reverting
@@ -60,26 +60,26 @@
         tree.add('new_file')
         basis_tree = tree.branch.repository.revision_tree(tree.last_revision())
         tree.revert()
-        self.failUnlessExists('tree/new_file')
+        self.assertPathExists('tree/new_file')
 
         # unchanged files should be deleted
         tree.add('new_file')
         tree.commit('add new_file')
         tree.revert(old_tree=basis_tree)
-        self.failIfExists('tree/new_file')
+        self.assertPathDoesNotExist('tree/new_file')
 
         # files should be deleted if their changes came from merges
         merge_target.merge_from_branch(tree.branch)
-        self.failUnlessExists('merge_target/new_file')
+        self.assertPathExists('merge_target/new_file')
         merge_target.revert()
-        self.failIfExists('merge_target/new_file')
+        self.assertPathDoesNotExist('merge_target/new_file')
 
         # files should not be deleted if changed after a merge
         merge_target.merge_from_branch(tree.branch)
-        self.failUnlessExists('merge_target/new_file')
+        self.assertPathExists('merge_target/new_file')
         self.build_tree_contents([('merge_target/new_file', 'new_contents')])
         merge_target.revert()
-        self.failUnlessExists('merge_target/new_file')
+        self.assertPathExists('merge_target/new_file')
 
     def tree_with_executable(self):
         tree = self.make_branch_and_tree('tree')
@@ -127,11 +127,11 @@
         tree.commit('added file', rev_id='rev1')
         os.unlink('file')
         tree.commit('removed file')
-        self.failIfExists('file')
+        self.assertPathDoesNotExist('file')
         tree.revert(old_tree=tree.branch.repository.revision_tree('rev1'))
-        self.failUnlessExists('file')
+        self.assertPathExists('file')
         tree.revert()
-        self.failIfExists('file')
+        self.assertPathDoesNotExist('file')
         self.assertEqual({}, tree.merge_modified())
 
     def test_empty_deprecated(self):
@@ -154,8 +154,8 @@
         os.rmdir('dir')
         tree.remove(['dir/', 'dir/file1', 'dir/file2'])
         tree.revert(['dir/file1'])
-        self.failUnlessExists('dir/file1')
-        self.failIfExists('dir/file2')
+        self.assertPathExists('dir/file1')
+        self.assertPathDoesNotExist('dir/file2')
         self.assertEqual('dir-id', tree.path2id('dir'))
 
     def test_revert_root_id_change(self):

=== modified file 'bzrlib/tests/test_script.py'
--- bzrlib/tests/test_script.py	2010-11-08 09:58:04 +0000
+++ bzrlib/tests/test_script.py	2011-04-15 07:01:22 +0000
@@ -383,8 +383,8 @@
 $ mkdir ../dir2
 $ cd ..
 """)
-        self.failUnlessExists('dir')
-        self.failUnlessExists('dir2')
+        self.assertPathExists('dir')
+        self.assertPathExists('dir2')
 
 
 class TestCd(script.TestCaseWithTransportAndScript):
@@ -416,7 +416,7 @@
             $ bzr init branch
             Created a standalone tree (format: ...)
             """)
-        self.failUnlessExists('branch')
+        self.assertPathExists('branch')
 
 
 class TestEcho(script.TestCaseWithMemoryTransportAndScript):
@@ -480,39 +480,39 @@
 
     def test_rm_file(self):
         self.run_script('$ echo content >file')
-        self.failUnlessExists('file')
+        self.assertPathExists('file')
         self.run_script('$ rm file')
-        self.failIfExists('file')
+        self.assertPathDoesNotExist('file')
 
     def test_rm_file_force(self):
-        self.failIfExists('file')
+        self.assertPathDoesNotExist('file')
         self.run_script('$ rm -f file')
-        self.failIfExists('file')
+        self.assertPathDoesNotExist('file')
 
     def test_rm_files(self):
         self.run_script("""
 $ echo content >file
 $ echo content >file2
 """)
-        self.failUnlessExists('file2')
+        self.assertPathExists('file2')
         self.run_script('$ rm file file2')
-        self.failIfExists('file2')
+        self.assertPathDoesNotExist('file2')
 
     def test_rm_dir(self):
         self.run_script('$ mkdir dir')
-        self.failUnlessExists('dir')
+        self.assertPathExists('dir')
         self.run_script("""
 $ rm dir
 2>rm: cannot remove 'dir': Is a directory
 """)
-        self.failUnlessExists('dir')
+        self.assertPathExists('dir')
 
     def test_rm_dir_recursive(self):
         self.run_script("""
 $ mkdir dir
 $ rm -r dir
 """)
-        self.failIfExists('dir')
+        self.assertPathDoesNotExist('dir')
 
 
 class TestMv(script.TestCaseWithTransportAndScript):
@@ -524,10 +524,10 @@
 
     def test_move_file(self):
         self.run_script('$ echo content >file')
-        self.failUnlessExists('file')
+        self.assertPathExists('file')
         self.run_script('$ mv file new_name')
-        self.failIfExists('file')
-        self.failUnlessExists('new_name')
+        self.assertPathDoesNotExist('file')
+        self.assertPathExists('new_name')
 
     def test_move_unknown_file(self):
         self.assertRaises(AssertionError,
@@ -539,9 +539,9 @@
 $ echo content >dir/file
 """)
         self.run_script('$ mv dir new_name')
-        self.failIfExists('dir')
-        self.failUnlessExists('new_name')
-        self.failUnlessExists('new_name/file')
+        self.assertPathDoesNotExist('dir')
+        self.assertPathExists('new_name')
+        self.assertPathExists('new_name/file')
 
     def test_move_file_into_dir(self):
         self.run_script("""
@@ -549,9 +549,9 @@
 $ echo content > file
 """)
         self.run_script('$ mv file dir')
-        self.failUnlessExists('dir')
-        self.failIfExists('file')
-        self.failUnlessExists('dir/file')
+        self.assertPathExists('dir')
+        self.assertPathDoesNotExist('file')
+        self.assertPathExists('dir/file')
 
 
 class cmd_test_confirm(commands.Command):

=== modified file 'bzrlib/tests/test_selftest.py'
--- bzrlib/tests/test_selftest.py	2011-04-14 07:53:38 +0000
+++ bzrlib/tests/test_selftest.py	2011-04-15 07:01:22 +0000
@@ -106,7 +106,7 @@
 
         filename = u'hell\u00d8'
         self.build_tree_contents([(filename, 'contents of hello')])
-        self.failUnlessExists(filename)
+        self.assertPathExists(filename)
 
 
 class TestClassesAvailable(tests.TestCase):
@@ -510,6 +510,25 @@
         self.assertRaises(AssertionError, self.assertEqualStat,
             os.lstat("foo"), os.lstat("longname"))
 
+    def test_failUnlessExists(self):
+        """Deprecated failUnlessExists and failIfExists"""
+        self.applyDeprecated(
+            deprecated_in((2, 4)),
+            self.failUnlessExists, '.')
+        self.build_tree(['foo/', 'foo/bar'])
+        self.applyDeprecated(
+            deprecated_in((2, 4)),
+            self.failUnlessExists, 'foo/bar')
+        self.applyDeprecated(
+            deprecated_in((2, 4)),
+            self.failIfExists, 'foo/foo')
+
+    def test_assertPathExists(self):
+        self.assertPathExists('.')
+        self.build_tree(['foo/', 'foo/bar'])
+        self.assertPathExists('foo/bar')
+        self.assertPathDoesNotExist('foo/foo')
+
 
 class TestTestCaseWithMemoryTransport(tests.TestCaseWithMemoryTransport):
 
@@ -662,7 +681,7 @@
     def test_make_branch_builder(self):
         builder = self.make_branch_builder('dir')
         rev_id = builder.build_commit()
-        self.failUnlessExists('dir')
+        self.assertPathExists('dir')
         a_dir = bzrdir.BzrDir.open('dir')
         self.assertRaises(errors.NoWorkingTree, a_dir.open_workingtree)
         a_branch = a_dir.open_branch()
@@ -684,7 +703,7 @@
         self.assertIsInstance(result_bzrdir.transport,
                               memory.MemoryTransport)
         # should not be on disk, should only be in memory
-        self.failIfExists('subdir')
+        self.assertPathDoesNotExist('subdir')
 
 
 class TestChrootedTest(tests.ChrootedTestCase):

=== modified file 'bzrlib/tests/test_sftp_transport.py'
--- bzrlib/tests/test_sftp_transport.py	2011-04-14 07:53:38 +0000
+++ bzrlib/tests/test_sftp_transport.py	2011-04-15 07:01:22 +0000
@@ -72,7 +72,7 @@
         t = self.get_transport()
 
         l = t.lock_write('bogus')
-        self.failUnlessExists('bogus.write-lock')
+        self.assertPathExists('bogus.write-lock')
 
         # Don't wait for the lock, locking an already locked
         # file should raise an assert

=== modified file 'bzrlib/tests/test_shelf.py'
--- bzrlib/tests/test_shelf.py	2011-01-12 18:25:01 +0000
+++ bzrlib/tests/test_shelf.py	2011-04-15 07:01:22 +0000
@@ -191,8 +191,8 @@
         s_trans_id = creator.shelf_transform.trans_id_file_id('foo-id')
         self.assertEqual('foo-id',
                          creator.shelf_transform.final_file_id(s_trans_id))
-        self.failIfExists('foo')
-        self.failIfExists('bar')
+        self.assertPathDoesNotExist('foo')
+        self.assertPathDoesNotExist('bar')
         self.assertShelvedFileEqual('a\n', creator, 'foo-id')
         s_bar_trans_id = creator.shelf_transform.trans_id_file_id('bar-id')
         self.assertEqual('directory',
@@ -231,7 +231,7 @@
             creator.shelve_creation('foo-id')
         creator.transform()
         s_trans_id = creator.shelf_transform.trans_id_file_id('foo-id')
-        self.failIfExists(link_name)
+        self.assertPathDoesNotExist(link_name)
         limbo_name = creator.shelf_transform._limbo_name(s_trans_id)
         self.assertEqual(link_target, osutils.readlink(limbo_name))
         ptree = creator.shelf_transform.get_preview_tree()
@@ -310,7 +310,7 @@
         s_trans_id = creator.shelf_transform.trans_id_file_id('foo-id')
         self.assertEqual('foo-id',
                          creator.shelf_transform.final_file_id(s_trans_id))
-        self.failIfExists('foo')
+        self.assertPathDoesNotExist('foo')
 
     def prepare_shelve_deletion(self):
         tree = self.make_branch_and_tree('tree')
@@ -362,7 +362,7 @@
                          sorted(list(creator.iter_shelvable())))
         creator.shelve_deletion('foo-id')
         creator.transform()
-        self.failUnlessExists('tree/foo')
+        self.assertPathExists('tree/foo')
 
     def prepare_shelve_change_kind(self):
         tree = self.make_branch_and_tree('tree')
@@ -421,7 +421,7 @@
                          sorted(list(creator.iter_shelvable())))
         creator.shelve_deletion('foo-id')
         creator.transform()
-        self.failUnlessExists('tree/foo')
+        self.assertPathExists('tree/foo')
 
     def test_shelve_serialization(self):
         tree = self.make_branch_and_tree('.')
@@ -636,12 +636,12 @@
             creator.shelve_change(change)
         shelf_manager = tree.get_shelf_manager()
         shelf_id = shelf_manager.shelve_changes(creator)
-        self.failIfExists('dir/subdir')
+        self.assertPathDoesNotExist('dir/subdir')
         tree.remove(['dir'])
         unshelver = shelf_manager.get_unshelver(shelf_id)
         self.addCleanup(unshelver.finalize)
         unshelver.make_merger().do_merge()
-        self.failUnlessExists('dir/subdir/foo')
+        self.assertPathExists('dir/subdir/foo')
         self.assertEqual('dir-id', tree.path2id('dir'))
         self.assertEqual('subdir-id', tree.path2id('dir/subdir'))
         self.assertEqual('foo-id', tree.path2id('dir/subdir/foo'))
@@ -746,7 +746,7 @@
         creator.shelve_creation('foo-id')
         shelf_manager = tree.get_shelf_manager()
         shelf_id = shelf_manager.shelve_changes(creator)
-        self.failIfExists('tree/foo')
+        self.assertPathDoesNotExist('tree/foo')
         unshelver = shelf_manager.get_unshelver(shelf_id)
         self.addCleanup(unshelver.finalize)
         unshelver.make_merger().do_merge()

=== modified file 'bzrlib/tests/test_shelf_ui.py'
--- bzrlib/tests/test_shelf_ui.py	2010-02-17 17:11:16 +0000
+++ bzrlib/tests/test_shelf_ui.py	2011-04-15 07:01:22 +0000
@@ -190,7 +190,7 @@
         shelver.expect('Shelve adding file "foo"? [yNfq?]', 'y')
         shelver.expect('Shelve 1 change(s)? [yNfq?]', 'y')
         shelver.run()
-        self.failIfExists('tree/foo')
+        self.assertPathDoesNotExist('tree/foo')
 
     def test_shelve_kind_change(self):
         tree = self.create_shelvable_tree()
@@ -422,7 +422,7 @@
         shelver.expect('Delete file "foo"? [yNfq?]', 'y')
         shelver.expect('Apply 1 change(s)? [yNfq?]', 'y')
         shelver.run()
-        self.failIfExists('tree/foo')
+        self.assertPathDoesNotExist('tree/foo')
 
     def test_shelve_kind_change(self):
         tree = self.create_shelvable_tree()

=== modified file 'bzrlib/tests/test_store.py'
--- bzrlib/tests/test_store.py	2011-04-14 07:53:38 +0000
+++ bzrlib/tests/test_store.py	2011-04-15 07:01:22 +0000
@@ -165,7 +165,7 @@
         s = self.get_store(u'.', compressed=False)
         cs.add(StringIO('hello there'), 'a')
 
-        self.failUnlessExists('a.gz')
+        self.assertPathExists('a.gz')
         self.assertFalse(os.path.lexists('a'))
 
         self.assertEquals(gzip.GzipFile('a.gz').read(), 'hello there')
@@ -178,7 +178,7 @@
         self.assertRaises(BzrError, s.add, StringIO('goodbye'), 'a')
 
         s.add(StringIO('goodbye'), 'b')
-        self.failUnlessExists('b')
+        self.assertPathExists('b')
         self.assertFalse(os.path.lexists('b.gz'))
         self.assertEquals(open('b').read(), 'goodbye')
 

=== modified file 'bzrlib/tests/test_subsume.py'
--- bzrlib/tests/test_subsume.py	2011-01-12 01:01:53 +0000
+++ bzrlib/tests/test_subsume.py	2011-04-15 07:01:22 +0000
@@ -64,14 +64,14 @@
         # this test checks the subdir is removed, so it needs to know the
         # control directory; that changes rarely so just hardcode (and check)
         # it is correct.
-        self.failUnlessExists('tree/subtree/.bzr')
+        self.assertPathExists('tree/subtree/.bzr')
         base_tree.subsume(sub_tree)
         self.assertEqual(['tree-1', 'subtree-1'], base_tree.get_parent_ids())
         self.assertEqual(sub_root_id, base_tree.path2id('subtree'))
         self.assertEqual('file2-id', base_tree.path2id('subtree/file2'))
         # subsuming the tree removes the control directory, so you can't open
         # it.
-        self.failIfExists('tree/subtree/.bzr')
+        self.assertPathDoesNotExist('tree/subtree/.bzr')
         file2 = open('tree/subtree/file2', 'rb')
         try:
             file2_contents = file2.read()

=== modified file 'bzrlib/tests/test_switch.py'
--- bzrlib/tests/test_switch.py	2011-01-12 01:01:53 +0000
+++ bzrlib/tests/test_switch.py	2011-04-15 07:01:22 +0000
@@ -53,12 +53,12 @@
             lightweight=self.lightweight)
         self.build_tree(['checkout/file-3'])
         checkout.add('file-3')
-        self.failIfExists('checkout/file-1')
-        self.failUnlessExists('checkout/file-2')
+        self.assertPathDoesNotExist('checkout/file-1')
+        self.assertPathExists('checkout/file-2')
         switch.switch(checkout.bzrdir, to_branch)
-        self.failUnlessExists('checkout/file-1')
-        self.failIfExists('checkout/file-2')
-        self.failUnlessExists('checkout/file-3')
+        self.assertPathExists('checkout/file-1')
+        self.assertPathDoesNotExist('checkout/file-2')
+        self.assertPathExists('checkout/file-3')
 
     def test_switch_after_branch_moved(self):
         """Test switch after the branch is moved."""
@@ -84,9 +84,9 @@
                 'Unable to connect to current master branch .*'
                 'To switch anyway, use --force.')
         switch.switch(checkout.bzrdir, to_branch, force=True)
-        self.failIfExists('checkout/file-1')
-        self.failUnlessExists('checkout/file-2')
-        self.failUnlessExists('checkout/file-3')
+        self.assertPathDoesNotExist('checkout/file-1')
+        self.assertPathExists('checkout/file-2')
+        self.assertPathExists('checkout/file-3')
 
     def test_switch_when_pending_merges(self):
         """Test graceful failure if pending merges are outstanding."""
@@ -120,8 +120,8 @@
         checkout = tree.branch.create_checkout('checkout',
             lightweight=self.lightweight)
         switch.switch(checkout.bzrdir, tree.branch, revision_id="rev1")
-        self.failUnlessExists('checkout/file-1')
-        self.failIfExists('checkout/file-2')
+        self.assertPathExists('checkout/file-1')
+        self.assertPathDoesNotExist('checkout/file-2')
 
     def test_switch_changing_root_id(self):
         tree = self._setup_tree()
@@ -179,13 +179,13 @@
         self.assertContainsRe(str(err),
             'Cannot switch as local commits found in the checkout.')
         # Check all is ok when force is given
-        self.failIfExists('checkout/file-1')
-        self.failUnlessExists('checkout/file-2')
+        self.assertPathDoesNotExist('checkout/file-1')
+        self.assertPathExists('checkout/file-2')
         switch.switch(checkout.bzrdir, to_branch, force=True)
-        self.failUnlessExists('checkout/file-1')
-        self.failIfExists('checkout/file-2')
-        self.failIfExists('checkout/file-3')
-        self.failUnlessExists('checkout/file-4')
+        self.assertPathExists('checkout/file-1')
+        self.assertPathDoesNotExist('checkout/file-2')
+        self.assertPathDoesNotExist('checkout/file-3')
+        self.assertPathExists('checkout/file-4')
         # Check that the checkout is a true mirror of the bound branch
         self.assertEqual(to_branch.last_revision_info(),
                          checkout.branch.last_revision_info())

=== modified file 'bzrlib/tests/test_transform.py'
--- bzrlib/tests/test_transform.py	2011-04-14 07:53:38 +0000
+++ bzrlib/tests/test_transform.py	2011-04-15 07:01:22 +0000
@@ -295,7 +295,7 @@
         trans_id = target_transform.create_path('file1', target_transform.root)
         target_transform.create_hardlink(self.wt.abspath('file1'), trans_id)
         target_transform.apply()
-        self.failUnlessExists('target/file1')
+        self.assertPathExists('target/file1')
         source_stat = os.stat(self.wt.abspath('file1'))
         target_stat = os.stat('target/file1')
         self.assertEqual(source_stat, target_stat)
@@ -467,8 +467,8 @@
         transform.new_file('FiLe', transform.root, 'content')
         resolve_conflicts(transform)
         transform.apply()
-        self.failUnlessExists('tree/file')
-        self.failUnlessExists('tree/FiLe.moved')
+        self.assertPathExists('tree/file')
+        self.assertPathExists('tree/FiLe.moved')
 
     def test_resolve_checkout_case_conflict(self):
         tree = self.make_branch_and_tree('tree')
@@ -483,8 +483,8 @@
         resolve_conflicts(transform,
                           pass_func=lambda t, c: resolve_checkout(t, c, []))
         transform.apply()
-        self.failUnlessExists('tree/file')
-        self.failUnlessExists('tree/FiLe.moved')
+        self.assertPathExists('tree/file')
+        self.assertPathExists('tree/FiLe.moved')
 
     def test_apply_case_conflict(self):
         """Ensure that a transform with case conflicts can always be applied"""
@@ -498,12 +498,12 @@
         transform.new_file('dirFiLe', dir, 'content')
         resolve_conflicts(transform)
         transform.apply()
-        self.failUnlessExists('tree/file')
+        self.assertPathExists('tree/file')
         if not os.path.exists('tree/FiLe.moved'):
-            self.failUnlessExists('tree/FiLe')
-        self.failUnlessExists('tree/dir/dirfile')
+            self.assertPathExists('tree/FiLe')
+        self.assertPathExists('tree/dir/dirfile')
         if not os.path.exists('tree/dir/dirFiLe.moved'):
-            self.failUnlessExists('tree/dir/dirFiLe')
+            self.assertPathExists('tree/dir/dirFiLe')
 
     def test_case_insensitive_limbo(self):
         tree = self.make_branch_and_tree('tree')
@@ -1255,8 +1255,8 @@
         parent2 = transform.new_directory('parent2', root)
         transform.adjust_path('child1', parent2, child1)
         transform.apply()
-        self.failIfExists(self.wt.abspath('parent1/child1'))
-        self.failUnlessExists(self.wt.abspath('parent2/child1'))
+        self.assertPathDoesNotExist(self.wt.abspath('parent1/child1'))
+        self.assertPathExists(self.wt.abspath('parent2/child1'))
         # rename limbo/new-1 => parent1, rename limbo/new-3 => parent2
         # no rename for child1 (counting only renames during apply)
         self.assertEqual(2, transform.rename_count)
@@ -1288,8 +1288,8 @@
         parent2 = transform.new_directory('parent2', root)
         transform.adjust_path('child1', parent2, child1)
         transform.apply()
-        self.failIfExists(self.wt.abspath('parent1'))
-        self.failUnlessExists(self.wt.abspath('parent2/child1'))
+        self.assertPathDoesNotExist(self.wt.abspath('parent1'))
+        self.assertPathExists(self.wt.abspath('parent2/child1'))
         # rename limbo/new-3 => parent2, rename limbo/new-2 => child1
         self.assertEqual(2, transform.rename_count)
 
@@ -1330,7 +1330,7 @@
         child = transform.new_directory('child', parent)
         transform.adjust_path('parent', root, parent)
         transform.apply()
-        self.failUnlessExists(self.wt.abspath('parent/child'))
+        self.assertPathExists(self.wt.abspath('parent/child'))
         self.assertEqual(1, transform.rename_count)
 
     def test_reuse_name(self):
@@ -1467,7 +1467,7 @@
         tt.create_file(["aa\n"], bar_trans_id)
         tt.version_file("bar-1", bar_trans_id)
         tt.apply()
-        self.failUnlessExists("foo/bar")
+        self.assertPathExists("foo/bar")
         wt.lock_read()
         try:
             self.assertEqual(wt.inventory.get_file_kind(wt.path2id("foo")),
@@ -1490,7 +1490,7 @@
         tt.delete_contents(foo_trans_id)
         tt.create_symlink("bar", foo_trans_id)
         tt.apply()
-        self.failUnlessExists("foo")
+        self.assertPathExists("foo")
         wt.lock_read()
         self.addCleanup(wt.unlock)
         self.assertEqual(wt.inventory.get_file_kind(wt.path2id("foo")),
@@ -1509,7 +1509,7 @@
         tt.delete_versioned(bar_trans_id)
         tt.create_file(["aa\n"], foo_trans_id)
         tt.apply()
-        self.failUnlessExists("foo")
+        self.assertPathExists("foo")
         wt.lock_read()
         self.addCleanup(wt.unlock)
         self.assertEqual(wt.inventory.get_file_kind(wt.path2id("foo")),
@@ -1530,8 +1530,8 @@
         self.build_tree(['baz'])
         tt.create_hardlink("baz", foo_trans_id)
         tt.apply()
-        self.failUnlessExists("foo")
-        self.failUnlessExists("baz")
+        self.assertPathExists("foo")
+        self.assertPathExists("baz")
         wt.lock_read()
         self.addCleanup(wt.unlock)
         self.assertEqual(wt.inventory.get_file_kind(wt.path2id("foo")),
@@ -1814,8 +1814,8 @@
         tree.add_reference(subtree)
         tree.commit('a revision')
         tree.branch.create_checkout('target')
-        self.failUnlessExists('target')
-        self.failUnlessExists('target/subtree')
+        self.assertPathExists('target')
+        self.assertPathExists('target/subtree')
 
     def test_file_conflict_handling(self):
         """Ensure that when building trees, conflict handling is done"""
@@ -1868,24 +1868,24 @@
         source.commit('added file')
         build_tree(source.basis_tree(), target)
         self.assertEqual([], target.conflicts())
-        self.failUnlessExists('target/dir1/file')
+        self.assertPathExists('target/dir1/file')
 
         # Ensure contents are merged
         target = self.make_branch_and_tree('target2')
         self.build_tree(['target2/dir1/', 'target2/dir1/file2'])
         build_tree(source.basis_tree(), target)
         self.assertEqual([], target.conflicts())
-        self.failUnlessExists('target2/dir1/file2')
-        self.failUnlessExists('target2/dir1/file')
+        self.assertPathExists('target2/dir1/file2')
+        self.assertPathExists('target2/dir1/file')
 
         # Ensure new contents are suppressed for existing branches
         target = self.make_branch_and_tree('target3')
         self.make_branch('target3/dir1')
         self.build_tree(['target3/dir1/file2'])
         build_tree(source.basis_tree(), target)
-        self.failIfExists('target3/dir1/file')
-        self.failUnlessExists('target3/dir1/file2')
-        self.failUnlessExists('target3/dir1.diverted/file')
+        self.assertPathDoesNotExist('target3/dir1/file')
+        self.assertPathExists('target3/dir1/file2')
+        self.assertPathExists('target3/dir1.diverted/file')
         self.assertEqual([DuplicateEntry('Diverted to',
             'dir1.diverted', 'dir1', 'new-dir1', None)],
             target.conflicts())
@@ -1894,9 +1894,9 @@
         self.build_tree(['target4/dir1/'])
         self.make_branch('target4/dir1/file')
         build_tree(source.basis_tree(), target)
-        self.failUnlessExists('target4/dir1/file')
+        self.assertPathExists('target4/dir1/file')
         self.assertEqual('directory', file_kind('target4/dir1/file'))
-        self.failUnlessExists('target4/dir1/file.diverted')
+        self.assertPathExists('target4/dir1/file.diverted')
         self.assertEqual([DuplicateEntry('Diverted to',
             'dir1/file.diverted', 'dir1/file', 'new-file', None)],
             target.conflicts())
@@ -2351,36 +2351,36 @@
         self.build_tree(['a/', 'a/b', 'c/', 'c/d'])
         mover = _FileMover()
         mover.rename('a', 'q')
-        self.failUnlessExists('q')
-        self.failIfExists('a')
-        self.failUnlessExists('q/b')
-        self.failUnlessExists('c')
-        self.failUnlessExists('c/d')
+        self.assertPathExists('q')
+        self.assertPathDoesNotExist('a')
+        self.assertPathExists('q/b')
+        self.assertPathExists('c')
+        self.assertPathExists('c/d')
 
     def test_pre_delete_rollback(self):
         self.build_tree(['a/'])
         mover = _FileMover()
         mover.pre_delete('a', 'q')
-        self.failUnlessExists('q')
-        self.failIfExists('a')
+        self.assertPathExists('q')
+        self.assertPathDoesNotExist('a')
         mover.rollback()
-        self.failIfExists('q')
-        self.failUnlessExists('a')
+        self.assertPathDoesNotExist('q')
+        self.assertPathExists('a')
 
     def test_apply_deletions(self):
         self.build_tree(['a/', 'b/'])
         mover = _FileMover()
         mover.pre_delete('a', 'q')
         mover.pre_delete('b', 'r')
-        self.failUnlessExists('q')
-        self.failUnlessExists('r')
-        self.failIfExists('a')
-        self.failIfExists('b')
+        self.assertPathExists('q')
+        self.assertPathExists('r')
+        self.assertPathDoesNotExist('a')
+        self.assertPathDoesNotExist('b')
         mover.apply_deletions()
-        self.failIfExists('q')
-        self.failIfExists('r')
-        self.failIfExists('a')
-        self.failIfExists('b')
+        self.assertPathDoesNotExist('q')
+        self.assertPathDoesNotExist('r')
+        self.assertPathDoesNotExist('a')
+        self.assertPathDoesNotExist('b')
 
     def test_file_mover_rollback(self):
         self.build_tree(['a/', 'a/b', 'c/', 'c/d/', 'c/e/'])
@@ -2391,8 +2391,8 @@
             mover.rename('a', 'c')
         except errors.FileExists, e:
             mover.rollback()
-        self.failUnlessExists('a')
-        self.failUnlessExists('c/d')
+        self.assertPathExists('a')
+        self.assertPathExists('c/d')
 
 
 class Bogus(Exception):
@@ -2428,11 +2428,11 @@
         tt.adjust_path('d', a_id, tt.trans_id_tree_path('a/b'))
         self.assertRaises(Bogus, tt.apply,
                           _mover=self.ExceptionFileMover(bad_source='a'))
-        self.failUnlessExists('a')
-        self.failUnlessExists('a/b')
+        self.assertPathExists('a')
+        self.assertPathExists('a/b')
         tt.apply()
-        self.failUnlessExists('c')
-        self.failUnlessExists('c/d')
+        self.assertPathExists('c')
+        self.assertPathExists('c/d')
 
     def test_rollback_rename_into_place(self):
         tree = self.make_branch_and_tree('.')
@@ -2444,11 +2444,11 @@
         tt.adjust_path('d', a_id, tt.trans_id_tree_path('a/b'))
         self.assertRaises(Bogus, tt.apply,
                           _mover=self.ExceptionFileMover(bad_target='c/d'))
-        self.failUnlessExists('a')
-        self.failUnlessExists('a/b')
+        self.assertPathExists('a')
+        self.assertPathExists('a/b')
         tt.apply()
-        self.failUnlessExists('c')
-        self.failUnlessExists('c/d')
+        self.assertPathExists('c')
+        self.assertPathExists('c/d')
 
     def test_rollback_deletion(self):
         tree = self.make_branch_and_tree('.')
@@ -2460,8 +2460,8 @@
         tt.adjust_path('d', tt.root, tt.trans_id_tree_path('a/b'))
         self.assertRaises(Bogus, tt.apply,
                           _mover=self.ExceptionFileMover(bad_target='d'))
-        self.failUnlessExists('a')
-        self.failUnlessExists('a/b')
+        self.assertPathExists('a')
+        self.assertPathExists('a/b')
 
 
 class TestTransformMissingParent(tests.TestCaseWithTransport):

=== modified file 'bzrlib/tests/test_treeshape.py'
--- bzrlib/tests/test_treeshape.py	2010-07-15 13:55:46 +0000
+++ bzrlib/tests/test_treeshape.py	2011-04-15 07:01:22 +0000
@@ -30,8 +30,8 @@
             ('.bzr/',),
             ('.bzr/README', 'hello'),
             ])
-        self.failUnlessExists('foo')
-        self.failUnlessExists('.bzr/README')
+        self.assertPathExists('foo')
+        self.assertPathExists('.bzr/README')
         self.assertFileEqual('hello', '.bzr/README')
 
     def test_build_tree_symlink(self):

=== modified file 'bzrlib/tests/test_uncommit.py'
--- bzrlib/tests/test_uncommit.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_uncommit.py	2011-04-15 07:01:22 +0000
@@ -49,7 +49,7 @@
         self.assertEqual((1, history[0]), tree.branch.last_revision_info())
 
         # The file should not be removed
-        self.failUnlessExists('tree/two')
+        self.assertPathExists('tree/two')
         # And it should still be listed as added
         self.assertIsNot(None, tree.path2id('two'))
 

=== modified file 'bzrlib/tests/test_upgrade.py'
--- bzrlib/tests/test_upgrade.py	2011-03-10 13:29:54 +0000
+++ bzrlib/tests/test_upgrade.py	2011-04-15 07:01:22 +0000
@@ -109,7 +109,7 @@
         self.assertEqual(rev_id, new_tree.last_revision())
         for path in ['basis-inventory-cache', 'inventory', 'last-revision',
             'pending-merges', 'stat-cache']:
-            self.failIfExists('tree/.bzr/checkout/' + path)
+            self.assertPathDoesNotExist('tree/.bzr/checkout/' + path)
 
     def test_convert_knit_merges_dirstate(self):
         tree = self.make_branch_and_tree('tree', format='knit')
@@ -127,7 +127,7 @@
         self.assertEqual([rev_id2, rev_id3], new_tree.get_parent_ids())
         for path in ['basis-inventory-cache', 'inventory', 'last-revision',
             'pending-merges', 'stat-cache']:
-            self.failIfExists('tree/.bzr/checkout/' + path)
+            self.assertPathDoesNotExist('tree/.bzr/checkout/' + path)
 
 
 class TestSmartUpgrade(tests.TestCaseWithTransport):
@@ -148,7 +148,7 @@
         self.assertLength(1, worked)
         self.assertEqual(worked[0], control)
         self.assertLength(0, issues)
-        self.failUnlessExists('branch1/backup.bzr.~1~')
+        self.assertPathExists('branch1/backup.bzr.~1~')
         self.assertEqual(control.open_repository()._format,
                          self.to_format._repository_format)
 
@@ -161,9 +161,9 @@
         self.assertLength(1, worked)
         self.assertEqual(worked[0], control)
         self.assertLength(0, issues)
-        self.failUnlessExists('branch1')
-        self.failUnlessExists('branch1/.bzr')
-        self.failIfExists('branch1/backup.bzr.~1~')
+        self.assertPathExists('branch1')
+        self.assertPathExists('branch1/.bzr')
+        self.assertPathDoesNotExist('branch1/backup.bzr.~1~')
         self.assertEqual(control.open_repository()._format,
                          self.to_format._repository_format)
 
@@ -187,9 +187,9 @@
         self.assertLength(3, worked)
         self.assertEqual(worked[0], control)
         self.assertLength(0, issues)
-        self.failUnlessExists('repo/backup.bzr.~1~')
-        self.failUnlessExists('repo/branch1/backup.bzr.~1~')
-        self.failUnlessExists('repo/branch2/backup.bzr.~1~')
+        self.assertPathExists('repo/backup.bzr.~1~')
+        self.assertPathExists('repo/branch1/backup.bzr.~1~')
+        self.assertPathExists('repo/branch2/backup.bzr.~1~')
         self.assertEqual(control.open_repository()._format,
                          self.to_format._repository_format)
         b1 = branch.Branch.open('repo/branch1')
@@ -204,11 +204,11 @@
         self.assertLength(3, worked)
         self.assertEqual(worked[0], control)
         self.assertLength(0, issues)
-        self.failUnlessExists('repo')
-        self.failUnlessExists('repo/.bzr')
-        self.failIfExists('repo/backup.bzr.~1~')
-        self.failIfExists('repo/branch1/backup.bzr.~1~')
-        self.failIfExists('repo/branch2/backup.bzr.~1~')
+        self.assertPathExists('repo')
+        self.assertPathExists('repo/.bzr')
+        self.assertPathDoesNotExist('repo/backup.bzr.~1~')
+        self.assertPathDoesNotExist('repo/branch1/backup.bzr.~1~')
+        self.assertPathDoesNotExist('repo/branch2/backup.bzr.~1~')
         self.assertEqual(control.open_repository()._format,
                          self.to_format._repository_format)
         b1 = branch.Branch.open('repo/branch1')

=== modified file 'bzrlib/tests/test_version.py'
--- bzrlib/tests/test_version.py	2011-01-12 01:01:53 +0000
+++ bzrlib/tests/test_version.py	2011-04-15 07:01:22 +0000
@@ -46,4 +46,4 @@
         out = sio.getvalue()
         m = re.search(r"Python interpreter: (.*) [0-9]", out)
         self.assertIsNot(m, None)
-        self.failUnlessExists(m.group(1))
+        self.assertPathExists(m.group(1))

=== modified file 'bzrlib/tests/test_workingtree.py'
--- bzrlib/tests/test_workingtree.py	2011-04-14 07:53:38 +0000
+++ bzrlib/tests/test_workingtree.py	2011-04-15 07:01:22 +0000
@@ -373,7 +373,7 @@
         self.build_tree_contents([('other/hello', 'hELLO')])
         other.commit('Case switch')
         this = base.bzrdir.sprout('this').open_workingtree()
-        self.failUnlessExists('this/hello')
+        self.assertPathExists('this/hello')
         self.build_tree_contents([('this/hello', 'Hello World')])
         this.commit('Add World')
         this.merge_from_branch(other.branch)
@@ -400,7 +400,7 @@
         self.assertEqual([], this.conflicts())
         self.assertEqual([conflicts.TextConflict('hello', 'hello_id')],
                          resolved)
-        self.failIfExists('this/hello.BASE')
+        self.assertPathDoesNotExist('this/hello.BASE')
 
     def test_auto_resolve_dir(self):
         tree = self.make_branch_and_tree('tree')

=== modified file 'doc/en/release-notes/bzr-2.4.txt'
--- doc/en/release-notes/bzr-2.4.txt	2011-04-15 23:42:57 +0000
+++ doc/en/release-notes/bzr-2.4.txt	2011-04-16 01:09:56 +0000
@@ -119,6 +119,11 @@
   on ``RepositoryFormat`` rather than a method on ``Repository``.
   (Jelmer Vernooij)
 
+* ``TestCase.failUnlessExists`` and ``failIfExists`` are deprecated in
+  favour of ``assertPathExists`` and ``assertPathDoesNotExist`` 
+  respectively.
+  (Martin Pool)
+
 * The ``revno`` parameter of ``log.LogRevision`` may now be None,
   representing a revision which is not in the current branch.
   (Matt Giuca, #241998)

